grammar pml2Joc;

@header {	package texToJoc;}

@members{  GestionJoc maGestionJoc;}

@lexer::header {package texToJoc;}

file
   :  enTete corpsTexte
   ;
corpsTexte   :  molecule finFichier  ;

enTete   :  (optionDeTex)?
         ;
//=============== caracteres de base =======================
blanc
   : BLANC { maGestionJoc.blanc(); }
   ;
caractere : CARACTERE { maGestionJoc.traiteCaractere($start.getText()); } ;
caractereAccentue : CARACTERE_ACCENTUE { maGestionJoc.traiteCaractereAccentue($start.getText()); } ;
caractereReserve : CARACTERE_RESERVE
               { maGestionJoc.traiteCaractereReserve($start.getText()); } ;
caracteresRestants	:	CARACTERES_RESTANTS  
			{ maGestionJoc.caracteresRestants($start.getText()); } ;
dQuote	:	DQUOTE	{ maGestionJoc.dQuote(); }	;
caractereComplet
   :  caractere | caractereAccentue | caractereReserve | blanc | caracteresRestants
   | caracteresMathML
   | lesReferences
   | uneCouleur
   | surligne | souligne 
   | lesAccentsSpeciaux   | dQuote
   ;
//============== basique =======================

chainePure :  	{ maGestionJoc.commenceNouvelleChaine(); }
     				(caractereComplet)+
   ;

chainePolicee
//   :  uneOuverturePolice ((chainePure | uneFormule) | labelFormule?) uneFermeturePolice
   :  uneOuverturePolice ((chainePure) | labelFormule?) uneFermeturePolice
   ;
entierChar	:	caractere+ ;

chainePoliceeMath
   :  ouvertureMath entierChar fermetureMath
   ;
   
atome		:	caractereComplet | contexteTexte  
			| typeRetourChariot | typeRetCharSpecial
			| centrage | theoreme
			| chainePolicee 
//			| chaineItalique | chaineItaliqueBold		//| chainePolicee 
//			| chaineRomane | chaineRomaneBold
			| uneFormule  
			| leHeader   | lesSections  | lesSources  | pageBreak
			;   
molecule	:		{ maGestionJoc.commenceNouvelleChaine(); }
				atome*
			;  
			 
finFichier 	:  EOF | FIN_CONTEXTE_TEXTE 
			| ( FIN_DOCUMENT  { maGestionJoc.finDocument(); } ) ;   
   
expression
   : chainePolicee  | unSingleton      | contexteTexte | theoreme
   | attributIndice | attributExposant
   | tableau | uneFormule  | centrage
  // | blanc
   ;

//================= option TeX et couleurs ===============
optionDeTex :  optionPlain | optionAMS | optionLatex  ;

optionPlain :  OPTION_PLAIN   { maGestionJoc.optionPlain(); }  ;
optionAMS   :  OPTION_AMS     { maGestionJoc.optionAMS(); }  ;
optionLatex :  OPTION_LATEX   { maGestionJoc.optionLaTeX(); }  ;
//===================== contextes ====================================
contexteTexte
   :  CONTEXTE_TEXTE       { maGestionJoc.contexteTexte(); }
      molecule
      FIN_CONTEXTE_TEXTE   { maGestionJoc.finContexteTexte(); }
   ;
centrage
   :  PAR_CENTRE       { maGestionJoc.centrage(); }
      molecule
      FIN_PAR_CENTRE   { maGestionJoc.finCentrage(); }
   ;
//==================== policees ===============

//chaineItalique			:	policeItalic molecule finPoliceItalic	;
//chaineItaliqueBold	:	italicBold molecule finItalicBold	;
//chaineRomane		:	policeRoman molecule finPoliceRoman	;
//chaineRomaneBold	:	romanBold molecule finRomanBold 	;
		
		
typeRetourChariot
   :  TYPE_RETOUR_CHARIOT
            { maGestionJoc.typeRetourChariot(); }
   ;
typeRetCharSpecial
   :  TYPE_RETOUR_CHARIOT_SPECIAL
      { maGestionJoc.typeRetCharSpecial(); }
   ;
		
uneCouleur
   :  debutCouleurs  { maGestionJoc.traiteDebutCouleur(); }
      chainePure
      finCouleurs    { maGestionJoc.traiteFinCouleur(); }
   ;
debutCouleurs :  DEBUT_COULEURS   ;
finCouleurs   :  FIN_COULEURS     ;
//======================== Singletons ==============================
unSingleton
   :  typeRetourChariot | typeRetCharSpecial | uneCouleur
   | surligne | souligne  //| taquet
   ;
   
pageBreak	:	SAUT_DE_PAGE  { maGestionJoc.pageBreak(); };
//===================== tableau ======================

entreeTableau
   :  taquet molecule
   ;
ligneTableau
   :  entreeLigne (entreeTableau)+
   ;

tableau
   :  CONTEXTE_TABLEAU  (uneCouleur)?     { maGestionJoc.tableau(); }
      (ligneTableau)+
      FIN_CONTEXTE_TABLEAU   { maGestionJoc.finTableau(); }
   ;
taquet
   :  ENTREE_TABLEAU         { maGestionJoc.taquet(); }
   ;

entreeLigne
:  ENTREE_LIGNE               { maGestionJoc.ligne(); }
;


//===================== contextes theoremes ============
theoreme
   :  DEF_THEOREME
      chainePure
      FIN_DEF_THEOREME  { maGestionJoc.contexteDefTheoreme(); }
      PAR_THEOREME      { maGestionJoc.contexteParTheoreme(); }
      molecule
      FIN_PAR_THEOREME  { maGestionJoc.finContexteParTheoreme(); }
   ;
//======================== attributs =================
surligne
   :  EN_SURLIGNER            { maGestionJoc.entreeSurligne(); }
      expressionMath
      FIN_EN_SURLIGNER        { maGestionJoc.surligne(); }
   ;
souligne
   :  EN_SOULIGNER            { maGestionJoc.entreeSouligne(); }
      expressionMath
      FIN_EN_SOULIGNER        { maGestionJoc.souligne(); }
   ;
attributIndice
   :  EN_INDICE         { maGestionJoc.entreeAttributIndice(); }
      expressionMath
      FIN_EN_INDICE     { maGestionJoc.attributIndice(); }
   ;
attributExposant
   :  EN_EXPOSANT       { maGestionJoc.entreeAttributExposant(); }
      expressionMath
      FIN_EN_EXPOSANT   { maGestionJoc.attributExposant(); }
   ;
//======================== polices Familles =================
taillePolice   : chainePure QUEUE_POLICE
                              { maGestionJoc.queuePolice(); } ;

uneOuverturePolice
   :  ouvertureRomane  | ouvertureItalienne | ouvertureBlackBd
   |  ouvertureCallig  | ouvertureSmc       | ouvertureGoth
   |  ouvertureTpw     | ouvertureUs //| ouvertureCy        
   |  ouvertureGrecque | ouvertureMath      | ouvertureMath2
   ;

ouvertureRomane
   :  policeRoman | romanSlanted | romanBold | romanSlantedBold ;
policeRoman       :  ROMAN_TEX taillePolice   { maGestionJoc.entreeRomane(0); } ;
romanSlanted      :  SLANTED_TEX taillePolice { maGestionJoc.entreeRomane(1); } ;
romanBold         :  BOLDFACE_TEX taillePolice { maGestionJoc.entreeRomane(2); } ;
romanSlantedBold  : SLANTED_BOLDFACE_TEX taillePolice { maGestionJoc.entreeRomane(3); } ;

ouvertureItalienne
   : policeItalic | italicSlanted | italicBold | italicSlantedBold ;
policeItalic      :  ITALIC_TEX taillePolice   { maGestionJoc.entreeItalique(0); } ;
italicSlanted     :  ITALIC_SLANTED_TEX taillePolice { maGestionJoc.entreeItalique(1); } ;
italicBold        :  ITALIC_BOLDFACE_TEX taillePolice  { maGestionJoc.entreeItalique(2); } ;
italicSlantedBold :  ITALIC_SLANTED_BOLDFACE_TEX taillePolice 
						{ maGestionJoc.entreeItalique(3); } ;

ouvertureBlackBd
   :  policeBlackBd | blackBdSlanted | blackBdBold | blackBdSlantedBold  ;
policeBlackBd   :  BLACKBOARD_TEX  taillePolice { maGestionJoc.entreeBlackBd(0); } ;
blackBdSlanted :  BLACKBOARD_SLANTED_TEX  taillePolice { maGestionJoc.entreeBlackBd(1); } ;
blackBdBold   :  BLACKBOARD_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeBlackBd(2); } ;
blackBdSlantedBold :  BLACKBOARD_SLANTED_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeBlackBd(3); } ;

ouvertureCallig
   :  policeCallig | calligSlanted | calligBold | calligSlantedBold  ;
policeCallig :  CALLIG_TEX  taillePolice { maGestionJoc.entreeCallig(0); } ;
calligSlanted :  CALLIG_SLANTED_TEX  taillePolice { maGestionJoc.entreeCallig(1); } ;
calligBold :  CALLIG_BOLDFACE_TEX  taillePolice  { maGestionJoc.entreeCallig(2); } ;
calligSlantedBold :  CALLIG_SLANTED_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeCallig(3); } ;

ouvertureSmc
   :  policeSmc | smcSlanted | smcBold | smcSlantedBold  ;
policeSmc :  SMALLCAP_TEX  taillePolice { maGestionJoc.entreeSmc(0); } ;
smcSlanted  :  SMALLCAP_SLANTED_TEX  taillePolice { maGestionJoc.entreeSmc(1); } ;
smcBold :  SMALLCAP_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeSmc(2); } ;
smcSlantedBold :  SMALLCAP_SLANTED_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeSmc(3); } ;

ouvertureGoth
   :  policeGoth | gothSlanted | gothBold | gothSlantedBold  ;
policeGoth :  GOTHIC_TEX  taillePolice { maGestionJoc.entreeGoth(0); } ;
gothSlanted  :  GOTHIC_SLANTED_TEX  taillePolice { maGestionJoc.entreeGoth(1); } ;
gothBold  :  GOTHIC_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeGoth(2); } ;
gothSlantedBold :  GOTHIC_SLANTED_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeGoth(3); } ;

ouvertureTpw
   :  policeTpw | tpwSlanted | tpwBold | tpwSlantedBold  ;
policeTpw  :  TYPEWRITER_TEX  taillePolice { maGestionJoc.entreeTpw(0); } ;
tpwSlanted :  TYPEWRITER_SLANTED_TEX  taillePolice { maGestionJoc.entreeTpw(1); } ;
tpwBold :  TYPEWRITER_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeTpw(2); } ;
tpwSlantedBold :  TYPEWRITER_SLANTED_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeTpw(3); } ;

/*ouvertureCy
   :  policeCy | cySlanted | cyBold | cySlantedBold  ;
policeCy        :  CYRILLIC_TEX                   taillePolice;
cySlanted       :  CYRILLIC_SLANTED_TEX           taillePolice;
cyBold          :  CYRILLIC_BOLDFACE_TEX          taillePolice;
cySlantedBold   :  CYRILLIC_SLANTED_BOLDFACE_TEX  taillePolice;
*/
ouvertureUs
   :  policeUs | usSlanted | usBold | usSlantedBold  ;
policeUs :  USER_TEX   taillePolice { maGestionJoc.entreeUs(0); } ;
usSlanted  :  USER_SLANTED_TEX  taillePolice { maGestionJoc.entreeUs(1); } ;
usBold :  USER_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeUs(2); } ;
usSlantedBold  :  USER_SLANTED_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeUs(3); } ;

ouvertureMath
   :  policeMath | mathSlanted | mathBold | mathSlantedBold  ;
policeMath :  MATHEMATIC_TEX  taillePolice { maGestionJoc.entreeMath(0); } ;
mathSlanted  :  MATHEMATIC_SLANTED_TEX  taillePolice { maGestionJoc.entreeMath(1); } ;
mathBold  :  MATHEMATIC_BOLDFACE_TEX  taillePolice  { maGestionJoc.entreeMath(2); } ;
mathSlantedBold :  MATHEMATIC_SLANTED_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeMath(3); } ;

ouvertureMath2
   :  policeMath2 | math2Slanted | math2Bold | math2SlantedBold  ;
policeMath2  :  MATHEMATIC2_TEX  taillePolice { maGestionJoc.entreeMath2(0); } ;
math2Slanted :  MATHEMATIC2_SLANTED_TEX  taillePolice { maGestionJoc.entreeMath2(1); } ;
math2Bold :  MATHEMATIC2_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeMath2(2); } ;
math2SlantedBold :  MATHEMATIC2_SLANTED_BOLDFACE_TEX  taillePolice { maGestionJoc.entreeMath2(3); } ;

ouvertureGrecque
   : policeGrecque | grecqueSlanted | grecqueBold | grecqueSlantedBold ;
policeGrecque  :  GRECQUE_TEX taillePolice { maGestionJoc.entreeGrecque(0); } ;
grecqueSlanted  :  GRECQUE_SLANTED_TEX taillePolice { maGestionJoc.entreeGrecque(1); } ;
grecqueBold :  GRECQUE_BOLDFACE_TEX taillePolice { maGestionJoc.entreeGrecque(2); } ;
grecqueSlantedBold :  GRECQUE_SLANTED_BOLDFACE_TEX taillePolice { maGestionJoc.entreeGrecque(3); } ;

//===================== fermetures polices =============================

uneFermeturePolice
   :  fermetureRomane  | fermetureItalienne | fermetureBlackBd
   |  fermetureCallig  | fermetureSmc       | fermetureGoth
   |  fermetureTpw     | fermetureUs			//| fermetureCy        
   |  fermetureGrecque | fermetureMath      | fermetureMath2
   ;
fermetureRomane
   : (finPoliceRoman | finRomanSlanted | finRomanBold 
   | finRomanSlantedBold) { maGestionJoc.sortiePolice(); } taillePolice ;
finPoliceRoman	:	FIN_ROMAN_TEX ;
finRomanSlanted   :  FIN_SLANTED_TEX  ;
finRomanBold   :  FIN_BOLDFACE_TEX  ;
finRomanSlantedBold : FIN_SLANTED_BOLDFACE_TEX ;

fermetureItalienne
 : (finPoliceItalic | finItalicSlanted | finItalicBold | finItalicSlantedBold)
  { maGestionJoc.sortiePolice(); } taillePolice ;
finPoliceItalic   :  FIN_ITALIC_TEX   ;
finItalicSlanted : FIN_ITALIC_SLANTED_TEX ;
finItalicBold : FIN_ITALIC_BOLDFACE_TEX ;
finItalicSlantedBold : FIN_ITALIC_SLANTED_BOLDFACE_TEX ;

fermetureBlackBd
   :  (finPoliceBlackBd | finBlackBdSlanted | finBlackBdBold
   | finBlackBdSlantedBold)  { maGestionJoc.sortiePolice(); } taillePolice ;
finPoliceBlackBd   :  FIN_BLACKBOARD_TEX  ;
finBlackBdSlanted   :  FIN_BLACKBOARD_SLANTED_TEX  ;
finBlackBdBold   :  FIN_BLACKBOARD_BOLDFACE_TEX ;
finBlackBdSlantedBold   :  FIN_BLACKBOARD_SLANTED_BOLDFACE_TEX ;

fermetureCallig
   : ( finPoliceCallig | finCalligSlanted | finCalligBold
   | finCalligSlantedBold ) { maGestionJoc.sortiePolice(); } taillePolice ;
finPoliceCallig   :  FIN_CALLIG_TEX  ;
finCalligSlanted   :  FIN_CALLIG_SLANTED_TEX ;
finCalligBold   :  FIN_CALLIG_BOLDFACE_TEX  ;
finCalligSlantedBold   :  FIN_CALLIG_SLANTED_BOLDFACE_TEX ;

fermetureSmc
   : ( finPoliceSmc | finSmcSlanted | finSmcBold 
   | finSmcSlantedBold ) { maGestionJoc.sortiePolice(); } taillePolice ;
finPoliceSmc   :  FIN_SMALLCAP_TEX  ;
finSmcSlanted   :  FIN_SMALLCAP_SLANTED_TEX  ;
finSmcBold   :  FIN_SMALLCAP_BOLDFACE_TEX ;
finSmcSlantedBold   :  FIN_SMALLCAP_SLANTED_BOLDFACE_TEX  ;

fermetureGoth
   : ( finPoliceGoth | finGothSlanted | finGothBold 
   | finGothSlantedBold ) { maGestionJoc.sortiePolice(); } taillePolice ;
finPoliceGoth   :  FIN_GOTHIC_TEX ;
finGothSlanted   :  FIN_GOTHIC_SLANTED_TEX  ;
finGothBold   :  FIN_GOTHIC_BOLDFACE_TEX  ;
finGothSlantedBold   :  FIN_GOTHIC_SLANTED_BOLDFACE_TEX  ;

fermetureTpw
   :(  finPoliceTpw | finTpwSlanted | finTpwBold 
   | finTpwSlantedBold)  { maGestionJoc.sortiePolice(); } taillePolice ;
finPoliceTpw   :  FIN_TYPEWRITER_TEX  ;
finTpwSlanted   :  FIN_TYPEWRITER_SLANTED_TEX   ;
finTpwBold   :  FIN_TYPEWRITER_BOLDFACE_TEX  ;
finTpwSlantedBold   :  FIN_TYPEWRITER_SLANTED_BOLDFACE_TEX ;

/*fermetureCy
   :  finPoliceCy | finCySlanted | finCyBold | finCySlantedBold  ;
finPoliceCy
   :  FIN_CYRILLIC_TEX                 { maGestionJoc.policeCy(0); }
      taillePolice ;
finCySlanted
   :  FIN_CYRILLIC_SLANTED_TEX         { maGestionJoc.policeCy(1); }
      taillePolice ;
finCyBold
   :  FIN_CYRILLIC_BOLDFACE_TEX        { maGestionJoc.policeCy(2); }
      taillePolice ;
finCySlantedBold
   :  FIN_CYRILLIC_SLANTED_BOLDFACE_TEX   { maGestionJoc.policeCy(3); }
      taillePolice ;
*/
fermetureUs
   :  (finPoliceUs | finUsSlanted | finUsBold 
   | finUsSlantedBold)   { maGestionJoc.sortiePolice(); } taillePolice ;
finPoliceUs   :  FIN_USER_TEX  ;
finUsSlanted   :  FIN_USER_SLANTED_TEX   ;
finUsBold   :  FIN_USER_BOLDFACE_TEX   ;
finUsSlantedBold   :  FIN_USER_SLANTED_BOLDFACE_TEX  ;

fermetureMath
   :  (finPoliceMath | finMathSlanted | finMathBold 
   | finMathSlantedBold)   { maGestionJoc.sortiePolice(); } taillePolice ;
finPoliceMath   :  FIN_MATHEMATIC_TEX  ;
finMathSlanted   :  FIN_MATHEMATIC_SLANTED_TEX  ;
finMathBold   :  FIN_MATHEMATIC_BOLDFACE_TEX ;
finMathSlantedBold   : FIN_MATHEMATIC_SLANTED_BOLDFACE_TEX  ;

fermetureMath2
   : ( finPoliceMath2 | finMath2Slanted | finMath2Bold 
   | finMath2SlantedBold ) { maGestionJoc.sortiePolice(); } taillePolice ;
finPoliceMath2   :  FIN_MATHEMATIC2_TEX  ;
finMath2Slanted   :  FIN_MATHEMATIC2_SLANTED_TEX  ;
finMath2Bold   :  FIN_MATHEMATIC2_BOLDFACE_TEX  ;
finMath2SlantedBold:  FIN_MATHEMATIC2_SLANTED_BOLDFACE_TEX ;

fermetureGrecque
 : (finPoliceGrecque | finGrecqueSlanted | finGrecqueBold 
 | finGrecqueSlantedBold) { maGestionJoc.sortiePolice(); } taillePolice ;
finPoliceGrecque   :  FIN_GRECQUE_TEX  ;
finGrecqueSlanted   :  FIN_GRECQUE_SLANTED_TEX  ;
finGrecqueBold   : FIN_GRECQUE_BOLDFACE_TEX  ;
finGrecqueSlantedBold   : FIN_GRECQUE_SLANTED_BOLDFACE_TEX ;

//======================== formules ==============================
//======================== formules ==============================
//======================== formules ==============================
//======================== formules ==============================
//======================== formules ==============================
uneFormule
   :  entreeFormule
      expressionMath
      finFormule
   ;
//========================= genres Formules =============
entreeFormule
   :   petiteFormule | petiteFormuleDisplay | formuleStandard | formuleLabellisee
   ;
petiteFormule		:	GENRE_LA_PETITE_FORMULE		{ maGestionJoc.petiteFormule(); } ;
petiteFormuleDisplay
	:	GENRE_LA_PETITE_FORMULE_DISPLAY { maGestionJoc.petiteFormuleDisplay(); } ;
formuleStandard
   	:  	GENRE_LA_FORMULE		{ maGestionJoc.formuleStandard(); } ;
formuleLabellisee
   	:  	GENRE_LA_FORMULE_LABEL		{ maGestionJoc.formuleLabellisee(); } ;
finFormule
   :  FIN_FORMULE                { maGestionJoc.finGenreFormule(); }
   ;
//=============== base maths=======================
labelFormule   :  	LABEL_FORMULE { maGestionJoc.entreeLabelFormule(); }
                 		chainePure
                 		 FIN_LABEL_FORMULE { maGestionJoc.labelFormule(); } ;

basiqueMath
   :  lesSymboles | expression  | labelFormule
   ;
expressionMath
   :  (basiqueMath)+
   ;
//=========== divers ======
caracteresMathML : inferieur | superieur | lOblique
                 ;
inferieur   :  INFERIEUR   { maGestionJoc.caracteresMathML('<'); } ;
superieur   :  SUPERIEUR   { maGestionJoc.caracteresMathML('>'); } ;
lOblique    :  L_OBLIQUE   { maGestionJoc.caracteresMathML('/'); } ;

//======================== symboles ==============================
lesSymboles
   :  lesMonos | lesDuos | lesTrios | matrice
   ;
//=================== monos ================
lesMonos
   :  parentheses      | exposant | crochets  | accoladeOuvrante
   |  accoladeFermante | parExces | parDefaut | indice
   |  prodScalaire     | norme    | racine    | valeurAbsolue
   | conjugue
   ;
//=============
finalMath
   :  finMono | finDuo | finTrio
   ;
leMonoCorps
   :  entreeCorps
      expressionMath
      finalMath      { maGestionJoc.finMono(); }
   ;
entreeCorps
   :  TYPE_CORPS
         { maGestionJoc.entreeCorps(); } ;
finMono
: FIN_MONOS | FIN_ENTIER_DEFAUT | FIN_ENTIER_EXCES | FIN_INDICE | FIN_EXPOSANT
| FIN_PROD_SCALAIRE | FIN_NORME | FIN_RACINE | FIN_VAL_ABSOLUE
| FIN_ACC_OUVRANTE | FIN_ACC_FERMANTE | FIN_PARENT_OUVRANTE
| FIN_PARENT_FERMANTE | FIN_CROCHET_OUVRANT | FIN_CROCHET_FERMANT
;
//===============
entreeParentheses
   :  PARENT_OUVRANTE (uneCouleur)?
         { maGestionJoc.entreeParentheses(); } ;
parentheses
   :  entreeParentheses
      leMonoCorps
   ;

entreeExposant
   :  EXPOSANT
         { maGestionJoc.entreeExposant(); } ;
exposant
   :  entreeExposant
      leMonoCorps
   ;

entreeCrochets
   :  CROCHET_OUVRANT (uneCouleur)?
         { maGestionJoc.entreeCrochets(); } ;
crochets
   :  entreeCrochets
      leMonoCorps
   ;

entreeAccoladeOuvrante
   :   ACC_OUVRANTE (uneCouleur)?
         { maGestionJoc.entreeAccoladeOuvrante(); } ;
accoladeOuvrante
   :  entreeAccoladeOuvrante
      leMonoCorps
   ;

entreeAccoladeFermante
   :   ACC_FERMANTE (uneCouleur)?
         { maGestionJoc.entreeAccoladeFermante(); } ;
accoladeFermante
   :  entreeAccoladeFermante
      leMonoCorps
   ;

entreeParExces
   :   ENTIER_EXCES (uneCouleur)?
         { maGestionJoc.entreeParExces(); } ;
parExces
   :  entreeParExces
      leMonoCorps
   ;

entreeParDefaut
   :   ENTIER_DEFAUT (uneCouleur)?
         { maGestionJoc.entreeParDefaut(); } ;
parDefaut
   :  entreeParDefaut
      leMonoCorps
   ;

entreeIndice
   :   INDICE
         { maGestionJoc.entreeIndice(); } ;
indice
   :  entreeIndice
      leMonoCorps
   ;

entreeProdScalaire
   :   PROD_SCALAIRE (uneCouleur)?
         { maGestionJoc.entreeProdScalaire(); } ;
prodScalaire
   :  entreeProdScalaire
      leMonoCorps
   ;

entreeNorme
   :   NORME (uneCouleur)?
         { maGestionJoc.entreeNorme(); } ;
norme
   :  entreeNorme
      leMonoCorps
   ;

entreeRacine
   :   RACINE (uneCouleur)?
         { maGestionJoc.entreeRacine(); } ;
racine
   :  entreeRacine
      leMonoCorps
   ;

entreeValeurAbsolue
   :   VAL_ABSOLUE (uneCouleur)?
         { maGestionJoc.entreeValeurAbsolue(); } ;
valeurAbsolue
   :  entreeValeurAbsolue
      leMonoCorps
   ;
   
entreeConjugue
   :   CONJUGATE (uneCouleur)?
         { maGestionJoc.entreeConjugue(); } ;
conjugue
   :  entreeConjugue
      leMonoCorps
   ;
   

//=================== duos ================
lesDuos
   :  fraction | overSet | underSet | genfrac
   ;
//=================
entreeNumerateur
   :  TYPE_NUMERATEUR
         { maGestionJoc.entreeNumerateur(); } ;
entreeDenominateur
   :  TYPE_DENOMINATEUR
         { maGestionJoc.entreeDenominateur(); } ;
finDuo
   :  FIN_FRACTION | FIN_PAR_DESSUS | FIN_PAR_DESSOUS | FIN_BINOMIALE
   |  FIN_GEN_FRAC
   ;
leDiCorps
   :  entreeNumerateur
         expressionMath
      entreeDenominateur
         expressionMath
      finalMath
   ;
//===============
entreeFraction
   :  FRACTION
         { maGestionJoc.entreeFraction(); } ;
fraction
   :  entreeFraction (uneCouleur)?
      leDiCorps
         { maGestionJoc.fraction(); }
   ;
entreeGenfrac
   :  GEN_FRAC
         { maGestionJoc.entreeGenfrac(); } ;
genfrac
   :  entreeGenfrac (uneCouleur)?
      leDiCorps
         { maGestionJoc.genfrac(); }
   ;

entreeOverSet
   :  PAR_DESSUS     { maGestionJoc.entreeOverSet(); } ;
overSet
   :  entreeOverSet (uneCouleur)?
      leDiCorps
         { maGestionJoc.overSet(); }
   ;
entreeUnderSet
   :  PAR_DESSOUS    { maGestionJoc.entreeUnderSet(); } ;
underSet
   :  entreeUnderSet (uneCouleur)?
      leDiCorps
         { maGestionJoc.underSet(); }
   ;
   
//=================== trios ===============
lesTrios
   :  union            | intersection | integrale | produitInfini
   |  produitVectoriel | sigma | span
   ;
//============
entreeBorneInf :  TYPE_BORNE_INF
                     { maGestionJoc.entreeBorneInf(); }
               ;
entreeBorneSup :  TYPE_BORNE_SUP
                     { maGestionJoc.entreeBorneSup(); }
               ;
entreeBorneCor :  TYPE_BORNE_COR
                     { maGestionJoc.entreeBorneCor(); }
               ;
finTrio
: (FIN_UNION | FIN_INTERSECTION | FIN_INTEGRALE | FIN_PROD_INFINI
   | FIN_PROD_VECTORIEL | FIN_SIGMA | FIN_SPAN )
                     { maGestionJoc.finTrio(); }
;
leTriCorps
   :  (entreeBorneInf expressionMath)?
      (entreeBorneSup expressionMath)?
      (entreeBorneCor expressionMath)?
      finalMath
   ;
//================SPAN
entreeSpan
   : SPAN (uneCouleur)?
         { maGestionJoc.entreeSpan(); }
   ;
span
   :  entreeSpan
      leTriCorps
   ;

entreeUnion
   : UNION (uneCouleur)?
         { maGestionJoc.entreeUnion(); }
   ;
union
   :  entreeUnion
      leTriCorps
   ;

entreeIntersection
   : INTERSECTION (uneCouleur)?
         { maGestionJoc.entreeIntersection(); }
   ;
intersection
   :  entreeIntersection
      leTriCorps
   ;

entreeIntegrale
   : INTEGRALE (uneCouleur)?
         { maGestionJoc.entreeIntegrale(); }
   ;
integrale
   :  entreeIntegrale
      leTriCorps
   ;

entreeProduitInfini
   : PROD_INFINI (uneCouleur)?
         { maGestionJoc.entreeProduitInfini(); }
   ;
produitInfini
   :  entreeProduitInfini
      leTriCorps
   ;

entreeProduitVectoriel
   : PROD_VECTORIEL (uneCouleur)?
         { maGestionJoc.entreeProduitVectoriel(); }
   ;
produitVectoriel
   :  entreeProduitVectoriel
      leTriCorps
   ;

entreeSigma
   : SIGMA (uneCouleur)?
         { maGestionJoc.entreeSigma(); }
   ;
sigma
   :  entreeSigma
      leTriCorps
   ;
//==================== matrice =============
borneEntree
   :  TYPE_BORNE_ENTREE       { maGestionJoc.borneEntree(); }
      (expressionMath)?
   ;
borneLigne
   :  TYPE_BORNE_LIGNE        { maGestionJoc.borneLigne(); }
      (borneEntree)*
   ;
matrice
   :  MATRICE (uneCouleur)?   { maGestionJoc.entreeMatrice(); }
      (borneLigne)+
      FIN_MATRICE        { maGestionJoc.matrice(); }
   ;
//======================= le Header =======================================
leHeader 	: titre | auteur | date | adresse | email | motsClefs | sujets
			| resume | sommaire ;
titre    : TITRE { maGestionJoc.titre(); } molecule FIN_TITRE  { maGestionJoc.finHeader(); }  ;
auteur   : AUTEUR { maGestionJoc.auteur(); } molecule FIN_AUTEUR  { maGestionJoc.finHeader(); }  ;
adresse   : ADRESSE { maGestionJoc.adresse(); }   molecule FIN_ADRESSE  { maGestionJoc.finHeader(); }  ;
email   : EMAIL { maGestionJoc.email(); }  molecule FIN_EMAIL  { maGestionJoc.finHeader(); }  ;
motsClefs   : MOTS_CLEFS { maGestionJoc.motsClefs(); }  molecule FIN_MOTS_CLEFS  { maGestionJoc.finHeader(); }  ;
sujets   : SUJETS { maGestionJoc.sujets(); } molecule FIN_SUJETS  { maGestionJoc.finHeader(); }  ;
date     : DATE { maGestionJoc.date(); } molecule FIN_DATE  { maGestionJoc.finHeader(); }  ;
resume   : RESUME { maGestionJoc.resume(); } molecule FIN_RESUME  { maGestionJoc.finHeader(); }  ;
sommaire : SOMMAIRE { maGestionJoc.sommaire(); } molecule FIN_SOMMAIRE  { maGestionJoc.finHeader(); }  ;
//======================= sections =======================================
lesSections : chapitre | paragraphe | sousParagraphe | sousSousParagraphe ;
finSection  : molecule (FIN_CHAPITRE | FIN_PARAGRAPHE
                           | FIN_SS_PARAGRAPHE | FIN_SS_SS_PARAGRAPHE)
                  { maGestionJoc.finSection(); } ;
chapitre :  CHAPITRE       { maGestionJoc.chapitre(); }     finSection ;
paragraphe :  PARAGRAPHE   { maGestionJoc.paragraphe(); }   finSection ;
sousParagraphe
   : SS_PARAGRAPHE    { maGestionJoc.sousParagraphe(); }       finSection ;
sousSousParagraphe
   :  SS_SS_PARAGRAPHE { maGestionJoc.sousSousParagraphe(); }  finSection ;
//======================= references =======================================
lesReferences
   :  reference | citation | citationBD | label | referencePar  ;

reference   :  GENRE_REFERENCE         { maGestionJoc.entreeReference(); }
               chainePure
               FIN_GENRE_REFERENCE     { maGestionJoc.reference(); } ;
citation    :  GENRE_CITATION          { maGestionJoc.entreeCitation(); }
               chainePure
               FIN_GENRE_CITATION      { maGestionJoc.citation(); } ;
citationBD  :   GENRE_CITATION_BD      { maGestionJoc.entreeCitationBD(); }
               chainePure
               FIN_GENRE_CITATION_BD   { maGestionJoc.citationBD(); } ;
source      :     GENRE_SOURCE         { maGestionJoc.entreeSource(); }
				CITE_SOURCE	
				chainePure
				FIN_CITE_SOURCE		 { maGestionJoc.finCiteSource(); }
              		molecule//chainePolicee+//chainePure // 
              		FIN_GENRE_SOURCE        { maGestionJoc.source(); } ;
label       :  GENRE_LABEL             { maGestionJoc.entreeLabel(); }
               chainePure
               FIN_GENRE_LABEL         { maGestionJoc.label(); } ;
referencePar : GENRE_REF_PAR           { maGestionJoc.entreeReferencePar(); }
               chainePure
               FIN_GENRE_REF_PAR       { maGestionJoc.referencePar(); } ;
finSource   :  GENRE_FIN_SOURCES       { maGestionJoc.entreeFinSource(); }
               chainePure
               FIN_GENRE_FIN_SOURCES   { maGestionJoc.finSource(); } ;
lesSources  :  source | finSource ;
//================== accents ========================
lesAccentsSpeciaux
	:	breveAcc | tildeAcc | circonflexeAcc | tremaAcc | pointAcc | checkAcc
	|	rondAcc | ogonekAcc | cedilleAcc
	;
breveAcc	:	 BREVE_ACC  { maGestionJoc.debSpeMath(); }
				caractere { maGestionJoc.accentSpeMath("breve"); }  ;
tildeAcc	:	 TILDE_ACC 	 { maGestionJoc.debSpeMath(); }
				caractere { maGestionJoc.accentSpeMath("tilde"); }  ;
circonflexeAcc	:	 CIRCONFLEXE_ACC { maGestionJoc.debSpeMath(); }
				caractere { maGestionJoc.accentSpeMath("circonflexe"); }  ;
tremaAcc	:	 TREMA_ACC  { maGestionJoc.debSpeMath(); }
				caractere { maGestionJoc.accentSpeMath("trema"); }  ;
pointAcc	:	 POINT_ACC  { maGestionJoc.debSpeMath(); }
				caractere { maGestionJoc.accentSpeMath("point"); }  ;
checkAcc	:	 CHECK_ACC  { maGestionJoc.debSpeMath(); }
				caractere { maGestionJoc.accentSpeMath("check"); }  ;
rondAcc	:	 ROND_ACC  { maGestionJoc.debSpeMath(); }
				caractere { maGestionJoc.accentSpeMath("rond"); }  ;
ogonekAcc	:	 OGONEK_ACC  { maGestionJoc.debSpeMath(); }
				caractere { maGestionJoc.accentSpeMath("ogonek"); }  ;
cedilleAcc	:	 CEDILLEE_ACC  { maGestionJoc.debSpeMath(); }
				caractere { maGestionJoc.accentSpeMath("cedille"); }  ;

//======================= fin du parser =======================================
//======================= fin du parser =======================================
//======================= fin du parser =======================================
//======================= fin du parser =======================================
//======================= fin du parser =======================================
//======================= fin du parser =======================================


//============== couleurs ============================
DEBUT_COULEURS    :  '<rgb(' ;
//============== fin couleurs ============================
FIN_COULEURS         :  ')/>'     ;
//==================
OPTION_PLAIN   :  '<PXplainTexOption>' ;
OPTION_AMS     :  '<PXAMSTexOption>'   ;
OPTION_LATEX   :  '<PXlaTexOption>'    ;
//=============== genre ... =========================================
GENRE_CITATION          :  '<citation>'     ;
GENRE_CITATION_BD       :  '<bibCitation>'  ;
GENRE_SOURCE            :  '<source>'       ;
GENRE_REFERENCE         :  '<reference>'    ;
GENRE_LABEL             :  '<label>'        ;
GENRE_REF_PAR           :  '<(reference)>'  ;
GENRE_FIN_SOURCES       :  '<fSources>'     ;

CITE_SOURCE			:	  '<citeSource>'       ;
FIN_CITE_SOURCE		:	  '</citeSource>'       ;
//=============== fin genre ... =========================================
FIN_GENRE_CITATION          :  '</citation>'    ;
FIN_GENRE_CITATION_BD       :  '</bibCitation>' ;
FIN_GENRE_SOURCE            :  '</source>'      ;
FIN_GENRE_REFERENCE         :  '</reference>'   ;
FIN_GENRE_LABEL             :  '</label>'       ;
FIN_GENRE_REF_PAR           :  '</(reference)>' ;
FIN_GENRE_FIN_SOURCES       :  '</fSources>'    ;
//==== mode formule ========
GENRE_LA_PETITE_FORMULE_DISPLAY  	:  '<dispFormula>'    ;
GENRE_LA_PETITE_FORMULE          		:  '<formula>'     ;
GENRE_LA_FORMULE                			:  '<centeredFormula>'  ;
GENRE_LA_FORMULE_LABEL       			:  '<labelledFormula>'  ;
//========= label Formule =================
LABEL_FORMULE              :  '<labelFormula>' ;
//==== fin mode formule ========
FIN_FORMULE                      :  '<endFormula>'   ;

GENRE_GRAPHIC                    :  '<graphic>'  ;
FIN_GENRE_GRAPHIC                :  '</graphic>' ;
//===================== contextes ====================================
CONTEXTE_TEXTE :  '<simpleText>' ;
PAR_SEPARE     :  '<separate>'      ;
PAR_CENTRE     :  '<center>'    ;

FIN_CONTEXTE_TEXTE :  '</simpleText>' ;
FIN_PAR_SEPARE     :  '</separate>'   ;
FIN_PAR_CENTRE     :  '</center>' ;

ENTREE_TABLEAU       :  '<entryTableau>'  ;
ENTREE_LIGNE         :  '<rowTableau>'    ;
CONTEXTE_TABLEAU     :  '<tableau>'       ;
FIN_CONTEXTE_TABLEAU :  '</tableau>'      ;


CONTEXTE_TEX_DIRECT  :  '<direct>' ;
CONTEXTE_INCLU_DOC   :  '<includeDoc>' ;

FIN_CONTEXTE_TEX_DIRECT  :  '</direct>' ;
FIN_CONTEXTE_INCLU_DOC   :  '</includeDoc>' ;

DEF_THEOREME         :  '<intitule>'   ;
PAR_THEOREME         :  '<statement>'     ;
FIN_DEF_THEOREME     :  '</intitule>'  ;
FIN_PAR_THEOREME     :  '</statement>'    ;
//======== header ======================
TITRE      :  '<title>'    ;
AUTEUR     :  '<author>'  ;
DATE       :  '<date>'     ;
ADRESSE       :  '<address>'     ;
EMAIL       :  '<email>'     ;
MOTS_CLEFS       :  '<keywords>'     ;
SUJETS       :  '<subjclass>'     ;
RESUME     :  '<abstract>'   ;
SOMMAIRE   :  '<content>' ;
//======== fin header ======================
FIN_TITRE      :  '</title>'    ;
FIN_AUTEUR     :  '</author>'  ;
FIN_DATE       :  '</date>'     ;
FIN_ADRESSE       :  '</address>'     ;
FIN_EMAIL       :  '</email>'     ;
FIN_MOTS_CLEFS       :  '</keywords>'     ;
FIN_SUJETS       :  '</subjclass>'     ;
FIN_RESUME     :  '</abstract>'   ;
FIN_SOMMAIRE   :  '</content>' ;
//======== section =======================
CHAPITRE         :  '<chapter>'     ;
PARAGRAPHE       :  '<section>'   ;
SS_PARAGRAPHE    :  '<subsection>'  ;
SS_SS_PARAGRAPHE :  '<subsubsection>' ;
//======== fin section =======================
FIN_CHAPITRE         :  '</chapter>'     ;
FIN_PARAGRAPHE       :  '</section>'   ;
FIN_SS_PARAGRAPHE    :  '</subsection>'  ;
FIN_SS_SS_PARAGRAPHE :  '</subsubsection>' ;
//========= reste ========================
//========= reste ========================
//========= reste ========================
//========= reste ========================
CONTEXTE_LISTE_NUMERISEE   :  '<numList>'   ;
//========= fin reste ========================
FIN_LABEL_FORMULE    :  '</labelFormula>';
FIN_CONTEXTE_LISTE_NUMERISEE   :  '</numList>' ;

//======================== attributs ==============================

EN_INDICE         :  '<atIndice>'   ;
EN_EXPOSANT       :  '<atExposant>' ;
EN_SURLIGNER      :  '<overline>' ;
EN_SOULIGNER      :  '<underline>' ;
//======================== fin attributs ==============================
FIN_EN_INDICE         :  '</atIndice>'   ;
FIN_EN_EXPOSANT       :  '</atExposant>' ;
FIN_EN_SURLIGNER      :  '</overline>' ;
FIN_EN_SOULIGNER      :  '</underline>' ;
//======================== polices =================
ROMAN_TEX               :  '<rm('  ;
SLANTED_TEX             :  '<rmS(' ;
BOLDFACE_TEX            :  '<rmB(' ;
SLANTED_BOLDFACE_TEX    :  '<rmSB(' ;

ITALIC_TEX                    :  '<it(' ;
ITALIC_SLANTED_TEX            :  '<itS(' ;
ITALIC_BOLDFACE_TEX           :  '<itB(' ;
ITALIC_SLANTED_BOLDFACE_TEX   :  '<itSB(' ;

BLACKBOARD_TEX                   :  '<bb(' ;
BLACKBOARD_SLANTED_TEX           :  '<bbS(' ;
BLACKBOARD_BOLDFACE_TEX          :  '<bbB(' ;
BLACKBOARD_SLANTED_BOLDFACE_TEX  :  '<bbSB(' ;

CALLIG_TEX                    :  '<rd(' ;
CALLIG_SLANTED_TEX            :  '<rdS(' ;
CALLIG_BOLDFACE_TEX           :  '<rdB(' ;
CALLIG_SLANTED_BOLDFACE_TEX   :  '<rdSB(' ;

SMALLCAP_TEX                  :  '<sc(' ;
SMALLCAP_SLANTED_TEX          :  '<scS(' ;
SMALLCAP_BOLDFACE_TEX         :  '<scB(' ;
SMALLCAP_SLANTED_BOLDFACE_TEX :  '<scSB(' ;

GOTHIC_TEX                    :  '<go(' ;
GOTHIC_SLANTED_TEX            :  '<goS(' ;
GOTHIC_BOLDFACE_TEX           :  '<goB(' ;
GOTHIC_SLANTED_BOLDFACE_TEX   :  '<goSB(' ;

MATHEMATIC_TEX                   :  '<mt(' ;
MATHEMATIC_SLANTED_TEX           :  '<mtS(' ;
MATHEMATIC_BOLDFACE_TEX          :  '<mtB(' ;
MATHEMATIC_SLANTED_BOLDFACE_TEX  :  '<mtSB(' ;

GRECQUE_TEX                   :  '<gr(' ;
GRECQUE_SLANTED_TEX           :  '<grS(' ;
GRECQUE_BOLDFACE_TEX          :  '<grB(' ;
GRECQUE_SLANTED_BOLDFACE_TEX  :  '<grSB(' ;

MATHEMATIC2_TEX                  :  '<m2(' ;
MATHEMATIC2_SLANTED_TEX          :  '<m2S(' ;
MATHEMATIC2_BOLDFACE_TEX         :  '<m2B(' ;
MATHEMATIC2_SLANTED_BOLDFACE_TEX :  '<m2SB(' ;

USER_TEX                  :  '<us(' ;
USER_SLANTED_TEX          :  '<usS(' ;
USER_BOLDFACE_TEX         :  '<usB(' ;
USER_SLANTED_BOLDFACE_TEX :  '<usSB(' ;

TYPEWRITER_TEX                    :  '<tt(' ;
TYPEWRITER_SLANTED_TEX            :  '<ttS(' ;
TYPEWRITER_BOLDFACE_TEX           :  '<ttB(' ;
TYPEWRITER_SLANTED_BOLDFACE_TEX   :  '<ttSB(' ;

QUEUE_POLICE                  :  ')font>' ;
DETROMP_QUEUE_POLICE          :  ')fon>' ;
//======================== fin polices =================
FIN_ROMAN_TEX                    :  '</rm(' ;
FIN_SLANTED_TEX                  :  '</rmS(' ;
FIN_BOLDFACE_TEX                 :  '</rmB(' ;
FIN_SLANTED_BOLDFACE_TEX         :  '</rmSB(' ;

FIN_ITALIC_TEX                    :  '</it(' ;
FIN_ITALIC_SLANTED_TEX            :  '</itS(' ;
FIN_ITALIC_BOLDFACE_TEX           :  '</itB(' ;
FIN_ITALIC_SLANTED_BOLDFACE_TEX   :  '</itSB(' ;

FIN_BLACKBOARD_TEX                   :  '</bb(' ;
FIN_BLACKBOARD_SLANTED_TEX           :  '</bbS(' ;
FIN_BLACKBOARD_BOLDFACE_TEX          :  '</bbB(' ;
FIN_BLACKBOARD_SLANTED_BOLDFACE_TEX  :  '</bbSB(' ;

FIN_CALLIG_TEX                    :  '</rd(' ;
FIN_CALLIG_SLANTED_TEX            :  '</rdS(' ;
FIN_CALLIG_BOLDFACE_TEX           :  '</rdB(' ;
FIN_CALLIG_SLANTED_BOLDFACE_TEX   :  '</rdSB(' ;

FIN_SMALLCAP_TEX                  :  '</sc(' ;
FIN_SMALLCAP_SLANTED_TEX          :  '</scS(' ;
FIN_SMALLCAP_BOLDFACE_TEX         :  '</scB(' ;
FIN_SMALLCAP_SLANTED_BOLDFACE_TEX :  '</scSB(' ;

FIN_GOTHIC_TEX                    :  '</go(' ;
FIN_GOTHIC_SLANTED_TEX            :  '</goS(' ;
FIN_GOTHIC_BOLDFACE_TEX           :  '</goB(' ;
FIN_GOTHIC_SLANTED_BOLDFACE_TEX   :  '</goSB(' ;

FIN_MATHEMATIC_TEX                   :  '</mt(' ;
FIN_MATHEMATIC_SLANTED_TEX           :  '</mtS(' ;
FIN_MATHEMATIC_BOLDFACE_TEX          :  '</mtB(' ;
FIN_MATHEMATIC_SLANTED_BOLDFACE_TEX  :  '</mtSB(' ;

FIN_GRECQUE_TEX                   :  '</gr(' ;
FIN_GRECQUE_SLANTED_TEX           :  '</grS(' ;
FIN_GRECQUE_BOLDFACE_TEX          :  '</grBf(' ;
FIN_GRECQUE_SLANTED_BOLDFACE_TEX  :  '</grSB(' ;

FIN_MATHEMATIC2_TEX                  :  '</m2(' ;
FIN_MATHEMATIC2_SLANTED_TEX          :  '</m2S(' ;
FIN_MATHEMATIC2_BOLDFACE_TEX         :  '</m2B(' ;
FIN_MATHEMATIC2_SLANTED_BOLDFACE_TEX :  '</m2SB(' ;

FIN_USER_TEX                  :  '</us(' ;
FIN_USER_SLANTED_TEX          :  '</usS(' ;
FIN_USER_BOLDFACE_TEX         :  '</usB(' ;
FIN_USER_SLANTED_BOLDFACE_TEX :  '</usSB(' ;

FIN_TYPEWRITER_TEX                    :  '</tt(' ;
FIN_TYPEWRITER_SLANTED_TEX            :  '</ttS(' ;
FIN_TYPEWRITER_BOLDFACE_TEX           :  '</ttB(' ;
FIN_TYPEWRITER_SLANTED_BOLDFACE_TEX   :  '</ttSB(' ;

//======================== types ==============================
//=== les symboles ===================
ENTIER_DEFAUT     		:  '<defInteger>'       ;
ENTIER_EXCES      		:  '<excesInteger>'        ;
INDICE            			:  '<msub>'             ;
EXPOSANT          			:  '<msup>'           ;
PROD_SCALAIRE     		:  '<scalProd>'    ;
NORME             			:  '<norm>'              ;
RACINE            			:  '<sqrt>'             ;
VAL_ABSOLUE       		:  '<absValue>'      ;
ACC_OUVRANTE      		:  '<opAccolade>'       ;
ACC_FERMANTE     	 	:  '<clAccolade>'       ;
PARENT_OUVRANTE   	:  '<opParenthesis>'     ;
PARENT_FERMANTE   	:  '<clParenthesis>'     ;
CROCHET_OUVRANT   	:  '<opBracket>'         ;
CROCHET_FERMANT   	:  '<clBracket>'         ;
CONJUGATE   				:  '<conjugate>'         ;

FRACTION          :  '<quotient>' ;
GEN_FRAC          :  '<genfrac>'           ;
PAR_DESSUS        :  '<overset>'  ;
PAR_DESSOUS       :  '<underset>' ;

UNION             :  '<union>'              ;
INTERSECTION      :  '<intersect>'       ;
INTEGRALE         :  '<int>'          ;
PROD_INFINI       :  '<product>'      ;
PROD_VECTORIEL    :  '<vectProd>'   ;
SIGMA             :  '<sum>'              ;
SPAN             :  '<span>'              ;

MATRICE           :  '<matrix>'            ;

//=== fin les symboles ===================
FIN_MONOS	:	 '</monos>'       ;
FIN_ENTIER_DEFAUT     :  '</defInteger>'       ;
FIN_ENTIER_EXCES      :  '</excesInteger>'        ;
FIN_INDICE            :  '</msub>'             ;
FIN_EXPOSANT          :  '</msup>'           ;
FIN_PROD_SCALAIRE     :  '</scalProd>'    ;
FIN_NORME             :  '</norm>'              ;
FIN_RACINE            :  '</sqrt>'             ;
FIN_VAL_ABSOLUE       :  '</absValue>'      ;
FIN_ACC_OUVRANTE      :  '</opAccolade>'       ;
FIN_ACC_FERMANTE      :  '</clAccolade>'       ;
FIN_PARENT_OUVRANTE   :  '</opParenthesis>'     ;
FIN_PARENT_FERMANTE   :  '</clParenthesis>'     ;
FIN_CROCHET_OUVRANT   :  '</opBracket>'         ;
FIN_CROCHET_FERMANT   	:  	'</clBracket>'         ;
FIN_CONJUGATE   			:  	'</conjugate>'         ;

FIN_FRACTION          :  '</quotient>'           ;
FIN_GEN_FRAC          :  '</genfrac>'           ;
FIN_PAR_DESSUS        :  '</overset>'  ;
FIN_PAR_DESSOUS       :  '</underset>' ;
FIN_BINOMIALE		: '</binom>' ;

FIN_UNION             :  '</union>'              ;
FIN_INTERSECTION      :  '</intersect>'       ;
FIN_INTEGRALE         :  '</int>'          ;
FIN_PROD_INFINI       :  '</product>'      ;
FIN_PROD_VECTORIEL    :  '</vectProd>'   ;
FIN_SIGMA             :  '</sum>'              ;
FIN_SPAN             :  '</span>'              ;

FIN_MATRICE           :  '</matrix>'            ;

//================== en relation avec les formules
TYPE_BORNE_INF    :  '<lowlimit>'           ;
TYPE_BORNE_SUP    :  '<uplimit>'           ;
TYPE_BORNE_COR    :  '<inlimit>'           ;
TYPE_BORNE_LIGNE  :  '<matrixrow>'         ;
TYPE_BORNE_ENTREE :  '<matrixentry>'        ;
TYPE_CORPS        :  '<inpart>'           ;
TYPE_NUMERATEUR   :  '<numerator>'      ;
TYPE_DENOMINATEUR :  '<denominator>'    ;
//================== fin en relation avec les formules
FIN_TYPE_BORNE_INF    :  '</lowlimit>'           ;
FIN_TYPE_BORNE_SUP    :  '</uplimit>'           ;
FIN_TYPE_BORNE_COR    :  '</inlimit>'           ;
FIN_TYPE_CORPS        :  '</inpart>'           ;
FIN_TYPE_NUMERATEUR   :  '</numerator>'      ;
FIN_TYPE_DENOMINATEUR :  '</denominator>'    ;
//==================== en relation avec les RC
TYPE_CURSEUR                  :  '<cursor>'         ;
TYPE_RETOUR_CHARIOT           :  '<caRet>'   ;
TYPE_RETOUR_CHARIOT_SPECIAL   :  '<caRetSpe>'  ;
TYPE_CARACTERE_COMPOSES       :  '<PXCaractereCompose>'      ;
//==================== fin en relation avec les RC
FIN_TYPE_RETOUR_CHARIOT          :  '</caRet>'   ;
FIN_TYPE_RETOUR_CHARIOT_SPECIAL  :  '</caRetSpe>'  ;
FIN_TYPE_CURSEUR                 :  '</cursor>'         ;
FIN_TYPE_CARACTERE_COMPOSES      :  '<PX/CaractereCompose>'      ;
//============ fin si la police doit etre change ================
TYPE_CARACTERE_DECALES      :  '<PXCarDecale>'             ;
// FIN_TYPE_CARACTERE_DECALES  :  '<PX/CarDecale>'             ;
//==================== MathML ================
INFERIEUR      :  '<lt/>' ;
SUPERIEUR      :  '<gt/>' ;
L_OBLIQUE      :  '<divide/>' ;
//==================== special accent ================
TILDE_ACC			:	'<tildeAcc/>' ;
CIRCONFLEXE_ACC			:	'<circonflexeAcc/>' ;
TREMA_ACC			:	'<tremaAcc/>' ;
POINT_ACC			:	'<pointAcc/>' ;
CHECK_ACC			:	'<checkAcc/>' ;
BREVE_ACC			:	'<breveAcc/>' ;
ROND_ACC			:	'<rondAcc/>' ;
OGONEK_ACC			:	'<ogonekAcc/>' ;
CEDILLEE_ACC			:	'<cedilleAcc/>' ;
//==================== special ================
DQUOTE	:	'\"' ;
//  -- ignored
WS :  (  '\t'
      |  '\f'
// handle newlines
      |  (  '\r\n'  // Evil DOS
      |  '\r'   // Macintosh
      |  '\n'   // Unix (the right way)
         )
      )  { skip(); }
   ;
BLANC :    ' '  ;
SAUT_DE_PAGE	:	'<pagebreak/>' ;
FIN_DOCUMENT	:	'<finDocument/>' ;
							
CARACTERE
   :  '!' | '\'' | '\''..'[' | ']' | '`'..'z'
   ;
/*CARACTERE_ACCENTUE	
		: '\u00E0' | '\u00E1' | '\u00E2' | '\u00E3' | '\u00E4' | '\u00E5' |'\u00E6' 
		| '\u00E8' | '\u00E9' | '\u00EA' | '\u00EB' 
		| '\u00EC' | '\u00E0D' | '\u00EE' | '\u00EF' 
		| '\u00F2' | '\u00F3' | '\u00F4' | '\u00F5' | '\u00F6' 
		| '\u00F9' | '\u00FA' | '\u00FB' | '\u00FC' 
		| '\u00E7' | '\u00F1' 
		| '\u00C0' | '\u00C1' | '\u00C2' | '\u00C3' | '\u00C4' | '\u00C5' |'\u00C8'
      | '\u00C9' | '\u00CA' | '\u00CB' | '\u00CC' | '\u00CD' | '\u00CE' | '\u00CF'
      | '\u00D2' | '\u00D3' |'\u00D4' | '\u00D5' | '\u00D6'
      | '\u00D9' | '\u00DA' |'\u00DB' |'\u00DC'
      | '\u00C7' | '\u00D1'
		;
*/
CARACTERE_RESERVE
   : '$' | '#' | '%' | '&' | '\\' | '{' | '}' | '^' | '_' | '~'
   ;
   
CARACTERES_RESTANTS	: '\u00FF'..'\uFFFF' ;
   
CARACTERE_ACCENTUE :  '\u00A1'..'\u00FF' ;
/*
CARACTERE_ACCENTUE : ~(
'&'
| '~'
| '|'
|'_'
|'^'
| '!'
| '\''
| '\''..'.'
| '0'..';'
| '='
| '?'..'['
| ']'
| '`'..'z'
| ' '
| '\\'
| '\t' | '\f' | '\n' | '\r'
| '>' | '<' | '/'
| '#'..'%' | '{' | '}'
) ;
*/

