grammar pml2Joc;

@header {	package texToJoc;}

@members{  GestionJoc maGestionJoc;}

@lexer::header {package texToJoc;}

file
   :  enTete listInstruc
   ;
instruc   :  expression	;//| uneFormule   ;
listInstruc   :  (instruc)+   ;

enTete   :  (optionDeTex)?
         ;
//=============== caracteres de base =======================
blanc
   : BLANC { maGestionJoc.blanc(); }
   ;
stca : CARACTERE { maGestionJoc.traiteCaractere($start.getText()); } ;
caractere
   : stca
   ;
stac : CARACTERE_ACCENTUE { maGestionJoc.traiteCaractereAccentue($start.getText()); } ;
caractereAccentue
   : stac
   ;
stre : CARACTERE_RESERVE
               { maGestionJoc.traiteCaractereReserve($start.getText()); } ;
caractereReserve
   : stre
   ;
caractereComplet
   :  caractere | caractereAccentue | caractereReserve | blanc
   | caracteresMathML
   | lesReferences
   | uneCouleur
   | surligne | souligne	
   ;
//============== basique =======================

chainePure :  	{ maGestionJoc.commenceNouvelleChaine(); }
     				(caractereComplet)+
   ;
chainePolicee
   :  uneOuverturePolice ((chainePure) | labelFormule?) uneFermeturePolice
   ;
expression
   : chainePolicee  | unSingleton      | contexteTexte | theoreme
   | attributIndice | attributExposant
   | leHeader       | lesSections      | lesSources    | centrage
   | tableau | uneFormule
  // | blanc
   ;

//================= option TeX et couleurs ===============
optionDeTex :  optionPlain | optionAMS | optionLatex  ;

optionPlain :  OPTION_PLAIN   { maGestionJoc.optionPlain(); }  ;
optionAMS   :  OPTION_AMS     { maGestionJoc.optionAMS(); }  ;
optionLatex :  OPTION_LATEX   { maGestionJoc.optionLaTeX(); }  ;

uneCouleur
   :  debutCouleurs  { maGestionJoc.traiteDebutCouleur(); }
      chainePure
      finCouleurs    { maGestionJoc.traiteFinCouleur(); }
   ;
debutCouleurs :  DEBUT_COULEURS   ;
finCouleurs   :  FIN_COULEURS     ;
//======================== Singletons ==============================
unSingleton
   :  typeRetourChariot | typeRetCharSpecial | uneCouleur
   | surligne | souligne   //| taquet
   ;
typeRetourChariot
   :  TYPE_RETOUR_CHARIOT
            { maGestionJoc.typeRetourChariot(); }
   ;
typeRetCharSpecial
   :  TYPE_RETOUR_CHARIOT_SPECIAL
      { maGestionJoc.typeRetCharSpecial(); }
   ;
//===================== contextes ====================================
contexteTexte
   :  CONTEXTE_TEXTE       { maGestionJoc.contexteTexte(); }
      (listInstruc)?
      FIN_CONTEXTE_TEXTE   { maGestionJoc.finContexteTexte(); }
   ;
centrage
   :  PAR_CENTRE       { maGestionJoc.centrage(); }
      listInstruc
      FIN_PAR_CENTRE   { maGestionJoc.finCentrage(); }
   ;
//===================== tableau ======================

entreeTableau
   :  taquet listInstruc
   ;
ligneTableau
   :  entreeLigne (entreeTableau)+
   ;

tableau
   :  CONTEXTE_TABLEAU  (uneCouleur)?     { maGestionJoc.tableau(); }
      (ligneTableau)+
      FIN_CONTEXTE_TABLEAU   { maGestionJoc.finTableau(); }
   ;
taquet
   :  ENTREE_TABLEAU         { maGestionJoc.taquet(); }
   ;

entreeLigne
:  ENTREE_LIGNE               { maGestionJoc.ligne(); }
;


//===================== contextes theoremes ============
theoreme
   :  DEF_THEOREME
      chainePure
      FIN_DEF_THEOREME  { maGestionJoc.contexteDefTheoreme(); }
      PAR_THEOREME      { maGestionJoc.contexteParTheoreme(); }
      listInstruc
      FIN_PAR_THEOREME  { maGestionJoc.finContexteParTheoreme(); }
   ;
//======================== attributs =================
surligne
   :  EN_SURLIGNER            { maGestionJoc.entreeSurligne(); }
      expressionMath
      FIN_EN_SURLIGNER        { maGestionJoc.surligne(); }
   ;
souligne
   :  EN_SOULIGNER            { maGestionJoc.entreeSouligne(); }
      expressionMath
      FIN_EN_SOULIGNER        { maGestionJoc.souligne(); }
   ;
attributIndice
   :  EN_INDICE         { maGestionJoc.entreeAttributIndice(); }
      expressionMath
      FIN_EN_INDICE     { maGestionJoc.attributIndice(); }
   ;
attributExposant
   :  EN_EXPOSANT       { maGestionJoc.entreeAttributExposant(); }
      expressionMath
      FIN_EN_EXPOSANT   { maGestionJoc.attributExposant(); }
   ;
//======================== polices Familles =================
taillePolice   : chainePure QUEUE_POLICE
                              { maGestionJoc.queuePolice(); } ;

uneOuverturePolice
   :  ouvertureRomane  | ouvertureItalienne | ouvertureBlackBd
   |  ouvertureCallig  | ouvertureSmc       | ouvertureGoth
   |  ouvertureTpw     | ouvertureUs //| ouvertureCy        
   |  ouvertureGrecque | ouvertureMath      | ouvertureMath2
   ;

ouvertureRomane
   :  policeRoman | romanSlanted | romanBold | romanSlantedBold ;
policeRoman       :  ROMAN_TEX taillePolice ;
romanSlanted      :  SLANTED_TEX taillePolice ;
romanBold         :  BOLDFACE_TEX taillePolice ;
romanSlantedBold  : SLANTED_BOLDFACE_TEX taillePolice ;

ouvertureItalienne
   : policeItalic | italicSlanted | italicBold | italicSlantedBold ;
policeItalic      :  ITALIC_TEX taillePolice ;
italicSlanted     :  ITALIC_SLANTED_TEX taillePolice ;
italicBold        :  ITALIC_BOLDFACE_TEX taillePolice ;
italicSlantedBold :  ITALIC_SLANTED_BOLDFACE_TEX taillePolice ;

ouvertureBlackBd
   :  policeBlackBd | blackBdSlanted | blackBdBold | blackBdSlantedBold  ;
policeBlackBd        :  BLACKBOARD_TEX                   taillePolice ;
blackBdSlanted       :  BLACKBOARD_SLANTED_TEX           taillePolice ;
blackBdBold          :  BLACKBOARD_BOLDFACE_TEX          taillePolice ;
blackBdSlantedBold   :  BLACKBOARD_SLANTED_BOLDFACE_TEX  taillePolice ;

ouvertureCallig
   :  policeCallig | calligSlanted | calligBold | calligSlantedBold  ;
policeCallig        :  CALLIG_TEX                   taillePolice ;
calligSlanted       :  CALLIG_SLANTED_TEX           taillePolice ;
calligBold          :  CALLIG_BOLDFACE_TEX          taillePolice ;
calligSlantedBold   :  CALLIG_SLANTED_BOLDFACE_TEX  taillePolice ;

ouvertureSmc
   :  policeSmc | smcSlanted | smcBold | smcSlantedBold  ;
policeSmc        :  SMALLCAP_TEX                   taillePolice ;
smcSlanted       :  SMALLCAP_SLANTED_TEX           taillePolice ;
smcBold          :  SMALLCAP_BOLDFACE_TEX          taillePolice ;
smcSlantedBold   :  SMALLCAP_SLANTED_BOLDFACE_TEX  taillePolice ;

ouvertureGoth
   :  policeGoth | gothSlanted | gothBold | gothSlantedBold  ;
policeGoth        :  GOTHIC_TEX                   taillePolice ;
gothSlanted       :  GOTHIC_SLANTED_TEX           taillePolice ;
gothBold          :  GOTHIC_BOLDFACE_TEX          taillePolice ;
gothSlantedBold   :  GOTHIC_SLANTED_BOLDFACE_TEX  taillePolice ;

ouvertureTpw
   :  policeTpw | tpwSlanted | tpwBold | tpwSlantedBold  ;
policeTpw        :  TYPEWRITER_TEX                   taillePolice ;
tpwSlanted       :  TYPEWRITER_SLANTED_TEX           taillePolice ;
tpwBold          :  TYPEWRITER_BOLDFACE_TEX          taillePolice ;
tpwSlantedBold   :  TYPEWRITER_SLANTED_BOLDFACE_TEX  taillePolice ;

/*ouvertureCy
   :  policeCy | cySlanted | cyBold | cySlantedBold  ;
policeCy        :  CYRILLIC_TEX                   taillePolice;
cySlanted       :  CYRILLIC_SLANTED_TEX           taillePolice;
cyBold          :  CYRILLIC_BOLDFACE_TEX          taillePolice;
cySlantedBold   :  CYRILLIC_SLANTED_BOLDFACE_TEX  taillePolice;
*/
ouvertureUs
   :  policeUs | usSlanted | usBold | usSlantedBold  ;
policeUs        :  USER_TEX                   taillePolice ;
usSlanted       :  USER_SLANTED_TEX           taillePolice ;
usBold          :  USER_BOLDFACE_TEX          taillePolice ;
usSlantedBold   :  USER_SLANTED_BOLDFACE_TEX  taillePolice ;

ouvertureMath
   :  policeMath | mathSlanted | mathBold | mathSlantedBold  ;
policeMath        :  MATHEMATIC_TEX                   taillePolice ;
mathSlanted       :  MATHEMATIC_SLANTED_TEX           taillePolice ;
mathBold          :  MATHEMATIC_BOLDFACE_TEX          taillePolice ;
mathSlantedBold   :  MATHEMATIC_SLANTED_BOLDFACE_TEX  taillePolice ;

ouvertureMath2
   :  policeMath2 | math2Slanted | math2Bold | math2SlantedBold  ;
policeMath2        :  MATHEMATIC2_TEX                   taillePolice ;
math2Slanted       :  MATHEMATIC2_SLANTED_TEX           taillePolice ;
math2Bold          :  MATHEMATIC2_BOLDFACE_TEX          taillePolice ;
math2SlantedBold   :  MATHEMATIC2_SLANTED_BOLDFACE_TEX  taillePolice ;

ouvertureGrecque
   : policeGrecque | grecqueSlanted | grecqueBold | grecqueSlantedBold ;
policeGrecque        :  GRECQUE_TEX taillePolice ;
grecqueSlanted       :  GRECQUE_SLANTED_TEX taillePolice ;
grecqueBold          :  GRECQUE_BOLDFACE_TEX taillePolice ;
grecqueSlantedBold   :  GRECQUE_SLANTED_BOLDFACE_TEX taillePolice ;

//===================== fermetures polices =============================

uneFermeturePolice
   :  fermetureRomane  | fermetureItalienne | fermetureBlackBd
   |  fermetureCallig  | fermetureSmc       | fermetureGoth
   |  fermetureTpw     | fermetureUs			//| fermetureCy        
   |  fermetureGrecque | fermetureMath      | fermetureMath2
   ;
fermetureRomane
   : finPoliceRoman | finRomanSlanted | finRomanBold | finRomanSlantedBold ;
finPoliceRoman    :  FIN_ROMAN_TEX     { maGestionJoc.policeRoman(0); }
                     taillePolice ;
finRomanSlanted   :  FIN_SLANTED_TEX   { maGestionJoc.policeRoman(1); }
                     taillePolice ;
finRomanBold   :  FIN_BOLDFACE_TEX     { maGestionJoc.policeRoman(2); }
                     taillePolice ;
finRomanSlantedBold : FIN_SLANTED_BOLDFACE_TEX
                                    { maGestionJoc.policeRoman(3); }
                      taillePolice ;

fermetureItalienne
 : finPoliceItalic | finItalicSlanted | finItalicBold | finItalicSlantedBold
 ;
finPoliceItalic   :  FIN_ITALIC_TEX    { maGestionJoc.policeItalic(0); }
                     taillePolice ;
finItalicSlanted : FIN_ITALIC_SLANTED_TEX { maGestionJoc.policeItalic(1);; }
                   taillePolice ;
finItalicBold : FIN_ITALIC_BOLDFACE_TEX  { maGestionJoc.policeItalic(2); }
                taillePolice ;
finItalicSlantedBold : FIN_ITALIC_SLANTED_BOLDFACE_TEX
                                    { maGestionJoc.policeItalic(3); }
                       taillePolice ;

fermetureBlackBd
   :  finPoliceBlackBd | finBlackBdSlanted | finBlackBdBold
   | finBlackBdSlantedBold  ;
finPoliceBlackBd
   :  FIN_BLACKBOARD_TEX   { maGestionJoc.policeBlackBd(0); }
      taillePolice ;
finBlackBdSlanted
   :  FIN_BLACKBOARD_SLANTED_TEX    { maGestionJoc.policeBlackBd(1); }
      taillePolice ;
finBlackBdBold
   :  FIN_BLACKBOARD_BOLDFACE_TEX   { maGestionJoc.policeBlackBd(2); }
      taillePolice ;
finBlackBdSlantedBold
   :  FIN_BLACKBOARD_SLANTED_BOLDFACE_TEX
                                 { maGestionJoc.policeBlackBd(3); }
      taillePolice ;

fermetureCallig
   :  finPoliceCallig | finCalligSlanted | finCalligBold
   | finCalligSlantedBold  ;
finPoliceCallig
   :  FIN_CALLIG_TEX             { maGestionJoc.policeCallig(0); }
      taillePolice ;
finCalligSlanted
   :  FIN_CALLIG_SLANTED_TEX     { maGestionJoc.policeCallig(1); }
      taillePolice ;
finCalligBold
   :  FIN_CALLIG_BOLDFACE_TEX    { maGestionJoc.policeCallig(2); }
      taillePolice ;
finCalligSlantedBold
   :  FIN_CALLIG_SLANTED_BOLDFACE_TEX { maGestionJoc.policeCallig(3); }
      taillePolice ;

fermetureSmc
   :  finPoliceSmc | finSmcSlanted | finSmcBold | finSmcSlantedBold  ;
finPoliceSmc
   :  FIN_SMALLCAP_TEX              { maGestionJoc.policeSmc(0); }
      taillePolice ;
finSmcSlanted
   :  FIN_SMALLCAP_SLANTED_TEX      { maGestionJoc.policeSmc(1); }
      taillePolice ;
finSmcBold
   :  FIN_SMALLCAP_BOLDFACE_TEX     { maGestionJoc.policeSmc(2); }
      taillePolice ;
finSmcSlantedBold
   :  FIN_SMALLCAP_SLANTED_BOLDFACE_TEX { maGestionJoc.policeSmc(3); }
      taillePolice ;

fermetureGoth
   :  finPoliceGoth | finGothSlanted | finGothBold | finGothSlantedBold  ;
finPoliceGoth
   :  FIN_GOTHIC_TEX                   { maGestionJoc.policeGoth(0); }
      taillePolice ;
finGothSlanted
   :  FIN_GOTHIC_SLANTED_TEX           { maGestionJoc.policeGoth(1); }
      taillePolice ;
finGothBold
   :  FIN_GOTHIC_BOLDFACE_TEX          { maGestionJoc.policeGoth(2); }
      taillePolice ;
finGothSlantedBold
   :  FIN_GOTHIC_SLANTED_BOLDFACE_TEX  { maGestionJoc.policeGoth(3); }
      taillePolice ;

fermetureTpw
   :  finPoliceTpw | finTpwSlanted | finTpwBold | finTpwSlantedBold  ;
finPoliceTpw
   :  FIN_TYPEWRITER_TEX               { maGestionJoc.policeTpw(0); }
      taillePolice ;
finTpwSlanted
   :  FIN_TYPEWRITER_SLANTED_TEX       { maGestionJoc.policeTpw(1); }
      taillePolice ;
finTpwBold
   :  FIN_TYPEWRITER_BOLDFACE_TEX      { maGestionJoc.policeTpw(2); }
      taillePolice ;
finTpwSlantedBold
   :  FIN_TYPEWRITER_SLANTED_BOLDFACE_TEX { maGestionJoc.policeTpw(3); }
      taillePolice ;

/*fermetureCy
   :  finPoliceCy | finCySlanted | finCyBold | finCySlantedBold  ;
finPoliceCy
   :  FIN_CYRILLIC_TEX                 { maGestionJoc.policeCy(0); }
      taillePolice ;
finCySlanted
   :  FIN_CYRILLIC_SLANTED_TEX         { maGestionJoc.policeCy(1); }
      taillePolice ;
finCyBold
   :  FIN_CYRILLIC_BOLDFACE_TEX        { maGestionJoc.policeCy(2); }
      taillePolice ;
finCySlantedBold
   :  FIN_CYRILLIC_SLANTED_BOLDFACE_TEX   { maGestionJoc.policeCy(3); }
      taillePolice ;
*/
fermetureUs
   :  finPoliceUs | finUsSlanted | finUsBold | finUsSlantedBold  ;
finPoliceUs
   :  FIN_USER_TEX                     { maGestionJoc.policeUs(0); }
      taillePolice ;
finUsSlanted
   :  FIN_USER_SLANTED_TEX             { maGestionJoc.policeUs(1); }
      taillePolice ;
finUsBold
   :  FIN_USER_BOLDFACE_TEX            { maGestionJoc.policeUs(2); }
      taillePolice ;
finUsSlantedBold
   :  FIN_USER_SLANTED_BOLDFACE_TEX    { maGestionJoc.policeUs(3); }
      taillePolice ;

fermetureMath
   :  finPoliceMath | finMathSlanted | finMathBold | finMathSlantedBold  ;
finPoliceMath
   :  FIN_MATHEMATIC_TEX         { maGestionJoc.policeMath(0); }
      taillePolice ;
finMathSlanted
   :  FIN_MATHEMATIC_SLANTED_TEX { maGestionJoc.policeMath(1); }
      taillePolice ;
finMathBold
   :  FIN_MATHEMATIC_BOLDFACE_TEX      { maGestionJoc.policeMath(2); }
      taillePolice ;
finMathSlantedBold
   : FIN_MATHEMATIC_SLANTED_BOLDFACE_TEX { maGestionJoc.policeMath(3); }
      taillePolice ;

fermetureMath2
   :  finPoliceMath2 | finMath2Slanted | finMath2Bold | finMath2SlantedBold  ;
finPoliceMath2
   :  FIN_MATHEMATIC2_TEX              { maGestionJoc.policeMath2(0); }
      taillePolice ;
finMath2Slanted
   :  FIN_MATHEMATIC2_SLANTED_TEX      { maGestionJoc.policeMath2(1); }
      taillePolice ;
finMath2Bold
   :  FIN_MATHEMATIC2_BOLDFACE_TEX     { maGestionJoc.policeMath2(2); }
      taillePolice ;
finMath2SlantedBold
:  FIN_MATHEMATIC2_SLANTED_BOLDFACE_TEX { maGestionJoc.policeMath2(3); }
   taillePolice ;

fermetureGrecque
 : finPoliceGrecque | finGrecqueSlanted | finGrecqueBold | finGrecqueSlantedBold
 ;
finPoliceGrecque
   :  FIN_GRECQUE_TEX         { maGestionJoc.policeGrecque(0); }
      taillePolice ;
finGrecqueSlanted
   :  FIN_GRECQUE_SLANTED_TEX    { maGestionJoc.policeGrecque(1); }
      taillePolice ;
finGrecqueBold
   : FIN_GRECQUE_BOLDFACE_TEX    { maGestionJoc.policeGrecque(2); }
      taillePolice ;
finGrecqueSlantedBold
   : FIN_GRECQUE_SLANTED_BOLDFACE_TEX { maGestionJoc.policeGrecque(3); }
      taillePolice ;

//======================== formules ==============================
//======================== formules ==============================
//======================== formules ==============================
//======================== formules ==============================
//======================== formules ==============================
uneFormule
   :  entreeFormule
      expressionMath
      finFormule
   ;
//========================= genres Formules =============
entreeFormule
   :   petiteFormule | petiteFormuleDisplay | formuleStandard
   ;
petiteFormule
   :  GENRE_LA_PETITE_FORMULE         { maGestionJoc.petiteFormule(); }
   ;
petiteFormuleDisplay
   :  GENRE_LA_PETITE_FORMULE_DISPLAY { maGestionJoc.petiteFormuleDisplay(); }
   ;
formuleStandard
   :   GENRE_LA_FORMULE                { maGestionJoc.formuleStandard(); }
   ;
finFormule
   :  FIN_FORMULE                { maGestionJoc.finGenreFormule(); }
   ;
//=============== base maths=======================
labelFormule   :  LABEL_FORMULE { maGestionJoc.entreeLabelFormule(); }
                  chainePure
                  FIN_LABEL_FORMULE { maGestionJoc.labelFormule(); }
               ;

basiqueMath
   :  lesSymboles | expression | labelFormule
   ;
expressionMath
   :  (basiqueMath)+
   ;
//=========== divers ======
caracteresMathML : inferieur | superieur | lOblique
                 ;
inferieur   :  INFERIEUR   { maGestionJoc.caracteresMathML('<'); } ;
superieur   :  SUPERIEUR   { maGestionJoc.caracteresMathML('>'); } ;
lOblique    :  L_OBLIQUE   { maGestionJoc.caracteresMathML('/'); } ;

//======================== symboles ==============================
lesSymboles
   :  lesMonos | lesDuos | lesTrios | matrice
   ;
//=================== monos ================
lesMonos
   :  parentheses      | exposant | crochets  | accoladeOuvrante
   |  accoladeFermante | parExces | parDefaut | indice
   |  prodScalaire     | norme    | racine    | valeurAbsolue
   ;
//=============
finalMath
   :  finMono | finDuo | finTrio
   ;
leMonoCorps
   :  entreeCorps
      expressionMath
      finalMath      { maGestionJoc.finMono(); }
   ;
entreeCorps
   :  TYPE_CORPS
         { maGestionJoc.entreeCorps(); } ;
finMono
: FIN_ENTIER_DEFAUT | FIN_ENTIER_EXCES | FIN_INDICE | FIN_EXPOSANT
| FIN_PROD_SCALAIRE | FIN_NORME | FIN_RACINE | FIN_VAL_ABSOLUE
| FIN_ACC_OUVRANTE | FIN_ACC_FERMANTE | FIN_PARENT_OUVRANTE
| FIN_PARENT_FERMANTE | FIN_CROCHET_OUVRANT | FIN_CROCHET_FERMANT
;
//===============
entreeParentheses
   :  PARENT_OUVRANTE (uneCouleur)?
         { maGestionJoc.entreeParentheses(); } ;
parentheses
   :  entreeParentheses
      leMonoCorps
   ;

entreeExposant
   :  EXPOSANT
         { maGestionJoc.entreeExposant(); } ;
exposant
   :  entreeExposant
      leMonoCorps
   ;

entreeCrochets
   :  CROCHET_OUVRANT (uneCouleur)?
         { maGestionJoc.entreeCrochets(); } ;
crochets
   :  entreeCrochets
      leMonoCorps
   ;

entreeAccoladeOuvrante
   :   ACC_OUVRANTE (uneCouleur)?
         { maGestionJoc.entreeAccoladeOuvrante(); } ;
accoladeOuvrante
   :  entreeAccoladeOuvrante
      leMonoCorps
   ;

entreeAccoladeFermante
   :   ACC_FERMANTE (uneCouleur)?
         { maGestionJoc.entreeAccoladeFermante(); } ;
accoladeFermante
   :  entreeAccoladeFermante
      leMonoCorps
   ;

entreeParExces
   :   ENTIER_EXCES (uneCouleur)?
         { maGestionJoc.entreeParExces(); } ;
parExces
   :  entreeParExces
      leMonoCorps
   ;

entreeParDefaut
   :   ENTIER_DEFAUT (uneCouleur)?
         { maGestionJoc.entreeParDefaut(); } ;
parDefaut
   :  entreeParDefaut
      leMonoCorps
   ;

entreeIndice
   :   INDICE
         { maGestionJoc.entreeIndice(); } ;
indice
   :  entreeIndice
      leMonoCorps
   ;

entreeProdScalaire
   :   PROD_SCALAIRE (uneCouleur)?
         { maGestionJoc.entreeProdScalaire(); } ;
prodScalaire
   :  entreeProdScalaire
      leMonoCorps
   ;

entreeNorme
   :   NORME (uneCouleur)?
         { maGestionJoc.entreeNorme(); } ;
norme
   :  entreeNorme
      leMonoCorps
   ;

entreeRacine
   :   RACINE (uneCouleur)?
         { maGestionJoc.entreeRacine(); } ;
racine
   :  entreeRacine
      leMonoCorps
   ;

entreeValeurAbsolue
   :   VAL_ABSOLUE (uneCouleur)?
         { maGestionJoc.entreeValeurAbsolue(); } ;
valeurAbsolue
   :  entreeValeurAbsolue
      leMonoCorps
   ;
//=================== duos ================
lesDuos
   :  fraction | overSet | underSet
   ;
//=================
entreeNumerateur
   :  TYPE_NUMERATEUR
         { maGestionJoc.entreeNumerateur(); } ;
entreeDenominateur
   :  TYPE_DENOMINATEUR
         { maGestionJoc.entreeDenominateur(); } ;
finDuo
   :  FIN_FRACTION | FIN_PAR_DESSUS | FIN_PAR_DESSOUS
   ;
leDiCorps
   :  entreeNumerateur
         expressionMath
      entreeDenominateur
         expressionMath
      finalMath
   ;
//===============
entreeFraction
   :  FRACTION
         { maGestionJoc.entreeFraction(); } ;
fraction
   :  entreeFraction (uneCouleur)?
      leDiCorps
         { maGestionJoc.fraction(); }
   ;
entreeOverSet
   :  PAR_DESSUS     { maGestionJoc.entreeOverSet(); } ;
overSet
   :  entreeOverSet (uneCouleur)?
      leDiCorps
         { maGestionJoc.overSet(); }
   ;
entreeUnderSet
   :  PAR_DESSOUS    { maGestionJoc.entreeUnderSet(); } ;
underSet
   :  entreeUnderSet (uneCouleur)?
      leDiCorps
         { maGestionJoc.underSet(); }
   ;
//=================== trios ===============
lesTrios
   :  union            | intersection | integrale | produitInfini
   |  produitVectoriel | sigma
   ;
//============
entreeBorneInf :  TYPE_BORNE_INF
                     { maGestionJoc.entreeBorneInf(); }
               ;
entreeBorneSup :  TYPE_BORNE_SUP
                     { maGestionJoc.entreeBorneSup(); }
               ;
entreeBorneCor :  TYPE_BORNE_COR
                     { maGestionJoc.entreeBorneCor(); }
               ;
finTrio
: (FIN_UNION | FIN_INTERSECTION | FIN_INTEGRALE | FIN_PROD_INFINI
   | FIN_PROD_VECTORIEL | FIN_SIGMA )
                     { maGestionJoc.finTrio(); }
;
leTriCorps
   :  (entreeBorneInf expressionMath)?
      (entreeBorneSup expressionMath)?
      (entreeBorneCor expressionMath)?
      finalMath
   ;
//================
entreeUnion
   : UNION (uneCouleur)?
         { maGestionJoc.entreeUnion(); }
   ;
union
   :  entreeUnion
      leTriCorps
   ;

entreeIntersection
   : INTERSECTION (uneCouleur)?
         { maGestionJoc.entreeIntersection(); }
   ;
intersection
   :  entreeIntersection
      leTriCorps
   ;

entreeIntegrale
   : INTEGRALE (uneCouleur)?
         { maGestionJoc.entreeIntegrale(); }
   ;
integrale
   :  entreeIntegrale
      leTriCorps
   ;

entreeProduitInfini
   : PROD_INFINI (uneCouleur)?
         { maGestionJoc.entreeProduitInfini(); }
   ;
produitInfini
   :  entreeProduitInfini
      leTriCorps
   ;

entreeProduitVectoriel
   : PROD_VECTORIEL (uneCouleur)?
         { maGestionJoc.entreeProduitVectoriel(); }
   ;
produitVectoriel
   :  entreeProduitVectoriel
      leTriCorps
   ;

entreeSigma
   : SIGMA (uneCouleur)?
         { maGestionJoc.entreeSigma(); }
   ;
sigma
   :  entreeSigma
      leTriCorps
   ;
//==================== matrice =============
borneEntree
   :  TYPE_BORNE_ENTREE       { maGestionJoc.borneEntree(); }
      (expressionMath)?
   ;
borneLigne
   :  TYPE_BORNE_LIGNE        { maGestionJoc.borneLigne(); }
      (borneEntree)+
   ;
matrice
   :  MATRICE (uneCouleur)?   { maGestionJoc.entreeMatrice(); }
      (borneLigne)+
      FIN_MATRICE        { maGestionJoc.matrice(); }
   ;
//======================= le Header =======================================
leHeader : titre | auteur | date | resume | sommaire ;
finHeader : listInstruc (FIN_TITRE | FIN_AUTEUR | FIN_DATE
                                   | FIN_RESUME | FIN_SOMMAIRE)
               { maGestionJoc.finHeader(); }
          ;
titre    : TITRE        { maGestionJoc.titre(); }     finHeader ;
auteur   : AUTEUR       { maGestionJoc.auteur(); }    finHeader ;
date     : DATE         { maGestionJoc.date(); }      finHeader ;
resume   : RESUME       { maGestionJoc.resume(); }    finHeader ;
sommaire : SOMMAIRE     { maGestionJoc.sommaire(); }  finHeader ;
//======================= sections =======================================
lesSections : chapitre | paragraphe | sousParagraphe | sousSousParagraphe ;
finSection  : listInstruc (FIN_CHAPITRE | FIN_PARAGRAPHE
                           | FIN_SS_PARAGRAPHE | FIN_SS_SS_PARAGRAPHE)
                  { maGestionJoc.finSection(); } ;
chapitre :  CHAPITRE       { maGestionJoc.chapitre(); }     finSection ;
paragraphe :  PARAGRAPHE   { maGestionJoc.paragraphe(); }   finSection ;
sousParagraphe
   : SS_PARAGRAPHE    { maGestionJoc.sousParagraphe(); }       finSection ;
sousSousParagraphe
   :  SS_SS_PARAGRAPHE { maGestionJoc.sousSousParagraphe(); }  finSection ;
//======================= references =======================================
lesReferences
   :  reference | citation | citationBD | label | referencePar  ;

reference   :  GENRE_REFERENCE         { maGestionJoc.entreeReference(); }
               chainePure
               FIN_GENRE_REFERENCE     { maGestionJoc.reference(); } ;
citation    :  GENRE_CITATION          { maGestionJoc.entreeCitation(); }
               chainePure
               FIN_GENRE_CITATION      { maGestionJoc.citation(); } ;
citationBD  :   GENRE_CITATION_BD      { maGestionJoc.entreeCitationBD(); }
               chainePure
               FIN_GENRE_CITATION_BD   { maGestionJoc.citationBD(); } ;
source      :     GENRE_SOURCE         { maGestionJoc.entreeSource(); }
               chainePure
               FIN_GENRE_SOURCE        { maGestionJoc.source(); } ;
label       :  GENRE_LABEL             { maGestionJoc.entreeLabel(); }
               chainePure
               FIN_GENRE_LABEL         { maGestionJoc.label(); } ;
referencePar : GENRE_REF_PAR           { maGestionJoc.entreeReferencePar(); }
               chainePure
               FIN_GENRE_REF_PAR       { maGestionJoc.referencePar(); } ;
finSource   :  GENRE_FIN_SOURCES       { maGestionJoc.entreeFinSource(); }
               chainePure
               FIN_GENRE_FIN_SOURCES   { maGestionJoc.finSource(); } ;
lesSources  :  source | finSource ;
//======================= fin du parser =======================================
//======================= fin du parser =======================================
//======================= fin du parser =======================================
//======================= fin du parser =======================================
//======================= fin du parser =======================================
//======================= fin du parser =======================================


//============== couleurs ============================
DEBUT_COULEURS    :  '<rgb(' ;
//============== fin couleurs ============================
FIN_COULEURS         :  ')/>'     ;
//==================
OPTION_PLAIN   :  '<PXplainTexOption>' ;
OPTION_AMS     :  '<PXAMSTexOption>'   ;
OPTION_LATEX   :  '<PXlaTexOption>'    ;
//=============== genre ... =========================================
GENRE_CITATION          :  '<citation>'     ;
GENRE_CITATION_BD       :  '<bibCitation>'  ;
GENRE_SOURCE            :  '<source>'       ;
GENRE_REFERENCE         :  '<reference>'    ;
GENRE_LABEL             :  '<label>'        ;
GENRE_REF_PAR           :  '<(reference)>'  ;
GENRE_FIN_SOURCES       :  '<fSources>'     ;
//=============== fin genre ... =========================================
FIN_GENRE_CITATION          :  '</citation>'    ;
FIN_GENRE_CITATION_BD       :  '</bibCitation>' ;
FIN_GENRE_SOURCE            :  '</source>'      ;
FIN_GENRE_REFERENCE         :  '</reference>'   ;
FIN_GENRE_LABEL             :  '</label>'       ;
FIN_GENRE_REF_PAR           :  '</(reference)>' ;
FIN_GENRE_FIN_SOURCES       :  '</fSources>'    ;
//==== mode formule ========
GENRE_LA_PETITE_FORMULE_DISPLAY  :  '<dispFormula>'    ;
GENRE_LA_PETITE_FORMULE          :  '<formula>'     ;
GENRE_LA_FORMULE                 :  '<centeredFormula>'  ;
//==== fin mode formule ========
FIN_FORMULE                      :  '<endFormula>'   ;

GENRE_GRAPHIC                    :  '<graphic>'  ;
FIN_GENRE_GRAPHIC                :  '</graphic>' ;
//===================== contextes ====================================
CONTEXTE_TEXTE :  '<simpleText>' ;
PAR_SEPARE     :  '<separate>'      ;
PAR_CENTRE     :  '<center>'    ;

FIN_CONTEXTE_TEXTE :  '</simpleText>' ;
FIN_PAR_SEPARE     :  '</separate>'   ;
FIN_PAR_CENTRE     :  '</center>' ;

ENTREE_TABLEAU       :  '<entryTableau>'  ;
ENTREE_LIGNE         :  '<rowTableau>'    ;
CONTEXTE_TABLEAU     :  '<tableau>'       ;
FIN_CONTEXTE_TABLEAU :  '</tableau>'      ;


CONTEXTE_TEX_DIRECT  :  '<direct>' ;
CONTEXTE_INCLU_DOC   :  '<includeDoc>' ;

FIN_CONTEXTE_TEX_DIRECT  :  '</direct>' ;
FIN_CONTEXTE_INCLU_DOC   :  '</includeDoc>' ;

DEF_THEOREME         :  '<intitule>'   ;
PAR_THEOREME         :  '<statement>'     ;
FIN_DEF_THEOREME     :  '</intitule>'  ;
FIN_PAR_THEOREME     :  '</statement>'    ;
//======== header ======================
TITRE      :  '<title>'    ;
AUTEUR     :  '<author>'  ;
DATE       :  '<date>'     ;
RESUME     :  '<abstract>'   ;
SOMMAIRE   :  '<content>' ;
//======== fin header ======================
FIN_TITRE      :  '</title>'    ;
FIN_AUTEUR     :  '</author>'  ;
FIN_DATE       :  '</date>'     ;
FIN_RESUME     :  '</abstract>'   ;
FIN_SOMMAIRE   :  '</content>' ;
//======== section =======================
CHAPITRE         :  '<chapter>'     ;
PARAGRAPHE       :  '<section>'   ;
SS_PARAGRAPHE    :  '<subsection>'  ;
SS_SS_PARAGRAPHE :  '<subsubsection>' ;
//======== fin section =======================
FIN_CHAPITRE         :  '</chapter>'     ;
FIN_PARAGRAPHE       :  '</section>'   ;
FIN_SS_PARAGRAPHE    :  '</subsection>'  ;
FIN_SS_SS_PARAGRAPHE :  '</subsubsection>' ;
//========= reste ========================
//========= reste ========================
//========= reste ========================
//========= reste ========================
LABEL_FORMULE              :  '<labelFormula>' ;
CONTEXTE_LISTE_NUMERISEE   :  '<numList>'   ;
//========= fin reste ========================
FIN_LABEL_FORMULE    :  '</labelFormula>';
FIN_CONTEXTE_LISTE_NUMERISEE   :  '</numList>' ;

//======================== attributs ==============================

EN_INDICE         :  '<atIndice>'   ;
EN_EXPOSANT       :  '<atExposant>' ;
EN_SURLIGNER      :  '<overline>' ;
EN_SOULIGNER      :  '<underline>' ;
//======================== fin attributs ==============================
FIN_EN_INDICE         :  '</atIndice>'   ;
FIN_EN_EXPOSANT       :  '</atExposant>' ;
FIN_EN_SURLIGNER      :  '</overline>' ;
FIN_EN_SOULIGNER      :  '</underline>' ;
//======================== polices =================
ROMAN_TEX               :  '<rm('  ;
SLANTED_TEX             :  '<rmS(' ;
BOLDFACE_TEX            :  '<rmB(' ;
SLANTED_BOLDFACE_TEX    :  '<rmSB(' ;

ITALIC_TEX                    :  '<it(' ;
ITALIC_SLANTED_TEX            :  '<itS(' ;
ITALIC_BOLDFACE_TEX           :  '<itB(' ;
ITALIC_SLANTED_BOLDFACE_TEX   :  '<itSB(' ;

BLACKBOARD_TEX                   :  '<bb(' ;
BLACKBOARD_SLANTED_TEX           :  '<bbS(' ;
BLACKBOARD_BOLDFACE_TEX          :  '<bbB(' ;
BLACKBOARD_SLANTED_BOLDFACE_TEX  :  '<bbSB(' ;

CALLIG_TEX                    :  '<rd(' ;
CALLIG_SLANTED_TEX            :  '<rdS(' ;
CALLIG_BOLDFACE_TEX           :  '<rdB(' ;
CALLIG_SLANTED_BOLDFACE_TEX   :  '<rdSB(' ;

SMALLCAP_TEX                  :  '<sc(' ;
SMALLCAP_SLANTED_TEX          :  '<scS(' ;
SMALLCAP_BOLDFACE_TEX         :  '<scB(' ;
SMALLCAP_SLANTED_BOLDFACE_TEX :  '<scSB(' ;

GOTHIC_TEX                    :  '<go(' ;
GOTHIC_SLANTED_TEX            :  '<goS(' ;
GOTHIC_BOLDFACE_TEX           :  '<goB(' ;
GOTHIC_SLANTED_BOLDFACE_TEX   :  '<goSB(' ;

MATHEMATIC_TEX                   :  '<mt(' ;
MATHEMATIC_SLANTED_TEX           :  '<mtS(' ;
MATHEMATIC_BOLDFACE_TEX          :  '<mtB(' ;
MATHEMATIC_SLANTED_BOLDFACE_TEX  :  '<mtSB(' ;

GRECQUE_TEX                   :  '<gr(' ;
GRECQUE_SLANTED_TEX           :  '<grS(' ;
GRECQUE_BOLDFACE_TEX          :  '<grB(' ;
GRECQUE_SLANTED_BOLDFACE_TEX  :  '<grSB(' ;

MATHEMATIC2_TEX                  :  '<m2(' ;
MATHEMATIC2_SLANTED_TEX          :  '<m2S(' ;
MATHEMATIC2_BOLDFACE_TEX         :  '<m2B(' ;
MATHEMATIC2_SLANTED_BOLDFACE_TEX :  '<m2SB(' ;

USER_TEX                  :  '<us(' ;
USER_SLANTED_TEX          :  '<usS(' ;
USER_BOLDFACE_TEX         :  '<usB(' ;
USER_SLANTED_BOLDFACE_TEX :  '<usSB(' ;

TYPEWRITER_TEX                    :  '<tt(' ;
TYPEWRITER_SLANTED_TEX            :  '<ttS(' ;
TYPEWRITER_BOLDFACE_TEX           :  '<ttB(' ;
TYPEWRITER_SLANTED_BOLDFACE_TEX   :  '<ttSB(' ;

QUEUE_POLICE                  :  ')font>' ;
DETROMP_QUEUE_POLICE          :  ')fon>' ;
//======================== fin polices =================
FIN_ROMAN_TEX                    :  '</rm(' ;
FIN_SLANTED_TEX                  :  '</rmS(' ;
FIN_BOLDFACE_TEX                 :  '</rmB(' ;
FIN_SLANTED_BOLDFACE_TEX         :  '</rmSB(' ;

FIN_ITALIC_TEX                    :  '</it(' ;
FIN_ITALIC_SLANTED_TEX            :  '</itS(' ;
FIN_ITALIC_BOLDFACE_TEX           :  '</itB(' ;
FIN_ITALIC_SLANTED_BOLDFACE_TEX   :  '</itSB(' ;

FIN_BLACKBOARD_TEX                   :  '</bb(' ;
FIN_BLACKBOARD_SLANTED_TEX           :  '</bbS(' ;
FIN_BLACKBOARD_BOLDFACE_TEX          :  '</bbB(' ;
FIN_BLACKBOARD_SLANTED_BOLDFACE_TEX  :  '</bbSB(' ;

FIN_CALLIG_TEX                    :  '</rd(' ;
FIN_CALLIG_SLANTED_TEX            :  '</rdS(' ;
FIN_CALLIG_BOLDFACE_TEX           :  '</rdB(' ;
FIN_CALLIG_SLANTED_BOLDFACE_TEX   :  '</rdSB(' ;

FIN_SMALLCAP_TEX                  :  '</sc(' ;
FIN_SMALLCAP_SLANTED_TEX          :  '</scS(' ;
FIN_SMALLCAP_BOLDFACE_TEX         :  '</scB(' ;
FIN_SMALLCAP_SLANTED_BOLDFACE_TEX :  '</scSB(' ;

FIN_GOTHIC_TEX                    :  '</go(' ;
FIN_GOTHIC_SLANTED_TEX            :  '</goS(' ;
FIN_GOTHIC_BOLDFACE_TEX           :  '</goB(' ;
FIN_GOTHIC_SLANTED_BOLDFACE_TEX   :  '</goSB(' ;

FIN_MATHEMATIC_TEX                   :  '</mt(' ;
FIN_MATHEMATIC_SLANTED_TEX           :  '</mtS(' ;
FIN_MATHEMATIC_BOLDFACE_TEX          :  '</mtB(' ;
FIN_MATHEMATIC_SLANTED_BOLDFACE_TEX  :  '</mtSB(' ;

FIN_GRECQUE_TEX                   :  '</gr(' ;
FIN_GRECQUE_SLANTED_TEX           :  '</grS(' ;
FIN_GRECQUE_BOLDFACE_TEX          :  '</grBf(' ;
FIN_GRECQUE_SLANTED_BOLDFACE_TEX  :  '</grSB(' ;

FIN_MATHEMATIC2_TEX                  :  '</m2(' ;
FIN_MATHEMATIC2_SLANTED_TEX          :  '</m2S(' ;
FIN_MATHEMATIC2_BOLDFACE_TEX         :  '</m2B(' ;
FIN_MATHEMATIC2_SLANTED_BOLDFACE_TEX :  '</m2SB(' ;

FIN_USER_TEX                  :  '</us(' ;
FIN_USER_SLANTED_TEX          :  '</usS(' ;
FIN_USER_BOLDFACE_TEX         :  '</usB(' ;
FIN_USER_SLANTED_BOLDFACE_TEX :  '</usSB(' ;

FIN_TYPEWRITER_TEX                    :  '</tt(' ;
FIN_TYPEWRITER_SLANTED_TEX            :  '</ttS(' ;
FIN_TYPEWRITER_BOLDFACE_TEX           :  '</ttB(' ;
FIN_TYPEWRITER_SLANTED_BOLDFACE_TEX   :  '</ttSB(' ;

//======================== types ==============================
//=== les symboles ===================
ENTIER_DEFAUT     :  '<defInteger>'       ;
ENTIER_EXCES      :  '<excesInteger>'        ;
INDICE            :  '<msub>'             ;
EXPOSANT          :  '<msup>'           ;
PROD_SCALAIRE     :  '<scalProd>'    ;
NORME             :  '<norm>'              ;
RACINE            :  '<sqrt>'             ;
VAL_ABSOLUE       :  '<absValue>'      ;
ACC_OUVRANTE      :  '<opAccolade>'       ;
ACC_FERMANTE      :  '<clAccolade>'       ;
PARENT_OUVRANTE   :  '<opParenthesis>'     ;
PARENT_FERMANTE   :  '<clParenthesis>'     ;
CROCHET_OUVRANT   :  '<opBracket>'         ;
CROCHET_FERMANT   :  '<clBracket>'         ;

FRACTION          :  '<quotient>' ;
PAR_DESSUS        :  '<overset>'  ;
PAR_DESSOUS       :  '<underset>' ;

UNION             :  '<union>'              ;
INTERSECTION      :  '<intersect>'       ;
INTEGRALE         :  '<int>'          ;
PROD_INFINI       :  '<product>'      ;
PROD_VECTORIEL    :  '<vectProd>'   ;
SIGMA             :  '<sum>'              ;

MATRICE           :  '<matrix>'            ;

//=== fin les symboles ===================
FIN_ENTIER_DEFAUT     :  '</defInteger>'       ;
FIN_ENTIER_EXCES      :  '</excesInteger>'        ;
FIN_INDICE            :  '</msub>'             ;
FIN_EXPOSANT          :  '</msup>'           ;
FIN_PROD_SCALAIRE     :  '</scalProd>'    ;
FIN_NORME             :  '</norm>'              ;
FIN_RACINE            :  '</sqrt>'             ;
FIN_VAL_ABSOLUE       :  '</absValue>'      ;
FIN_ACC_OUVRANTE      :  '</opAccolade>'       ;
FIN_ACC_FERMANTE      :  '</clAccolade>'       ;
FIN_PARENT_OUVRANTE   :  '</opParenthesis>'     ;
FIN_PARENT_FERMANTE   :  '</clParenthesis>'     ;
FIN_CROCHET_OUVRANT   :  '</opBracket>'         ;
FIN_CROCHET_FERMANT   :  '</clBracket>'         ;

FIN_FRACTION          :  '</quotient>'           ;
FIN_PAR_DESSUS        :  '</overset>'  ;
FIN_PAR_DESSOUS       :  '</underset>' ;

FIN_UNION             :  '</union>'              ;
FIN_INTERSECTION      :  '</intersect>'       ;
FIN_INTEGRALE         :  '</int>'          ;
FIN_PROD_INFINI       :  '</product>'      ;
FIN_PROD_VECTORIEL    :  '</vectProd>'   ;
FIN_SIGMA             :  '</sum>'              ;

FIN_MATRICE           :  '</matrix>'            ;

//================== en relation avec les formules
TYPE_BORNE_INF    :  '<lowlimit>'           ;
TYPE_BORNE_SUP    :  '<uplimit>'           ;
TYPE_BORNE_COR    :  '<inlimit>'           ;
TYPE_BORNE_LIGNE  :  '<matrixrow>'         ;
TYPE_BORNE_ENTREE :  '<matrixentry>'        ;
TYPE_CORPS        :  '<inpart>'           ;
TYPE_NUMERATEUR   :  '<numerator>'      ;
TYPE_DENOMINATEUR :  '<denominator>'    ;
//================== fin en relation avec les formules
FIN_TYPE_BORNE_INF    :  '</lowlimit>'           ;
FIN_TYPE_BORNE_SUP    :  '</uplimit>'           ;
FIN_TYPE_BORNE_COR    :  '</inlimit>'           ;
FIN_TYPE_CORPS        :  '</inpart>'           ;
FIN_TYPE_NUMERATEUR   :  '</numerator>'      ;
FIN_TYPE_DENOMINATEUR :  '</denominator>'    ;
//==================== en relation avec les RC
TYPE_CURSEUR                  :  '<cursor>'         ;
TYPE_RETOUR_CHARIOT           :  '<caRet>'   ;
TYPE_RETOUR_CHARIOT_SPECIAL   :  '<caRetSpe>'  ;
TYPE_CARACTERE_COMPOSES       :  '<PXCaractereCompose>'      ;
//==================== fin en relation avec les RC
FIN_TYPE_RETOUR_CHARIOT          :  '</caRet>'   ;
FIN_TYPE_RETOUR_CHARIOT_SPECIAL  :  '</caRetSpe>'  ;
FIN_TYPE_CURSEUR                 :  '</cursor>'         ;
FIN_TYPE_CARACTERE_COMPOSES      :  '<PX/CaractereCompose>'      ;
//============ fin si la police doit etre change ================
TYPE_CARACTERE_DECALES      :  '<PXCarDecale>'             ;
// FIN_TYPE_CARACTERE_DECALES  :  '<PX/CarDecale>'             ;
//==================== MathML ================
INFERIEUR      :  '<lt/>' ;
SUPERIEUR      :  '<gt/>' ;
L_OBLIQUE      :  '<divide/>' ;
//==================== special ================
//  -- ignored
WS :  (  '\t'
      |  '\f'
// handle newlines
      |  (  '\r\n'  // Evil DOS
      |  '\r'   // Macintosh
      |  '\n'   // Unix (the right way)
         )
      )  { skip(); }
   ;
BLANC :    ' '  ;
CARACTERE
   :  '!' | '\'' | '\''..'[' | ']' | '`'..'z'
   ;
CARACTERE_RESERVE
   : '$' | '#' | '%' | '&' | '\\' | '{' | '}' | '^' | '_' | '~'
   ;
//CARACTERE_ACCENTUE
  // :  '\u00A1'..'\u00FF'
   //;
CARACTERE_ACCENTUE : ~(
'&'
| '~'
| '|'
|'_'
|'^'
| '!'
| '\''
| '\''..'.'
| '0'..';'
| '='
| '?'..'['
| ']'
| '`'..'z'
| ' '
| '\\'
| '\t' | '\f' | '\n' | '\r'
| '>' | '<' | '/'
| '#'..'%' | '{' | '}'
) ;


